// ----------------------------------------------------------------------------
// Murphy.h
// ----------------------------------------------------------------------------

#ifndef MURPHY_H
#define MURPHY_H

#include "global.h"

extern void subAdjustZonksInfotronsAboveMurphy(int);
extern void subAnimateMurphy(int *);
extern void subCopyFieldToScreen(int, int);
extern void subCopyImageToScreen(int, int);
extern void subCopyAnimToScreen(int, int, int);
extern void subExplodeSnikSnaksBelow(int);
extern void subSpPortTest(int);

#endif /* MURPHY_H */
