/***********************************************************
* Rocks'n'Diamonds -- McDuffin Strikes Back!               *
*----------------------------------------------------------*
* (c) 1995-2006 Artsoft Entertainment                      *
*               Holger Schemel                             *
*               Detmolder Strasse 189                      *
*               33604 Bielefeld                            *
*               Germany                                    *
*               e-mail: info@artsoft.org                   *
*----------------------------------------------------------*
* conf_gfx.h                                               *
***********************************************************/

/* ----- this file was automatically generated -- do not edit by hand ----- */

#ifndef CONF_GFX_H
#define CONF_GFX_H

/* values for graphics configuration (normal elements) */

#define IMG_BD_WALL					0
#define IMG_BD_WALL_EDITOR				1
#define IMG_BD_ROCK					2
#define IMG_BD_ROCK_EDITOR				3
#define IMG_BD_ROCK_MOVING_LEFT				4
#define IMG_BD_ROCK_MOVING_RIGHT			5
#define IMG_BD_ROCK_PUSHING_LEFT			6
#define IMG_BD_ROCK_PUSHING_RIGHT			7
#define IMG_BD_DIAMOND					8
#define IMG_BD_DIAMOND_MOVING				9
#define IMG_BD_DIAMOND_FALLING				10
#define IMG_BD_MAGIC_WALL				11
#define IMG_BD_MAGIC_WALL_ACTIVE			12
#define IMG_BD_MAGIC_WALL_FILLING			13
#define IMG_BD_MAGIC_WALL_FULL				14
#define IMG_BD_MAGIC_WALL_EMPTYING			15
#define IMG_BD_MAGIC_WALL_DEAD				16
#define IMG_BD_AMOEBA					17
#define IMG_BD_AMOEBA_EDITOR				18
#define IMG_BD_BUTTERFLY				19
#define IMG_BD_BUTTERFLY_RIGHT				20
#define IMG_BD_BUTTERFLY_RIGHT_EDITOR			21
#define IMG_BD_BUTTERFLY_UP				22
#define IMG_BD_BUTTERFLY_UP_EDITOR			23
#define IMG_BD_BUTTERFLY_LEFT				24
#define IMG_BD_BUTTERFLY_LEFT_EDITOR			25
#define IMG_BD_BUTTERFLY_DOWN				26
#define IMG_BD_BUTTERFLY_DOWN_EDITOR			27
#define IMG_BD_FIREFLY					28
#define IMG_BD_FIREFLY_RIGHT				29
#define IMG_BD_FIREFLY_RIGHT_EDITOR			30
#define IMG_BD_FIREFLY_UP				31
#define IMG_BD_FIREFLY_UP_EDITOR			32
#define IMG_BD_FIREFLY_LEFT				33
#define IMG_BD_FIREFLY_LEFT_EDITOR			34
#define IMG_BD_FIREFLY_DOWN				35
#define IMG_BD_FIREFLY_DOWN_EDITOR			36
#define IMG_SP_DEFAULT_EXPLODING			37
#define IMG_SP_ZONK					38
#define IMG_SP_ZONK_MOVING_LEFT				39
#define IMG_SP_ZONK_MOVING_RIGHT			40
#define IMG_SP_ZONK_PUSHING_LEFT			41
#define IMG_SP_ZONK_PUSHING_RIGHT			42
#define IMG_SP_BASE					43
#define IMG_SP_BASE_DIGGING				44
#define IMG_SP_BASE_SNAPPING				45
#define IMG_SP_MURPHY					46
#define IMG_SP_MURPHY_MOVING_LEFT			47
#define IMG_SP_MURPHY_MOVING_RIGHT			48
#define IMG_SP_MURPHY_DIGGING_LEFT			49
#define IMG_SP_MURPHY_DIGGING_RIGHT			50
#define IMG_SP_MURPHY_COLLECTING_LEFT			51
#define IMG_SP_MURPHY_COLLECTING_RIGHT			52
#define IMG_SP_MURPHY_PUSHING_LEFT			53
#define IMG_SP_MURPHY_PUSHING_RIGHT			54
#define IMG_SP_MURPHY_SNAPPING_LEFT			55
#define IMG_SP_MURPHY_SNAPPING_RIGHT			56
#define IMG_SP_MURPHY_SNAPPING_UP			57
#define IMG_SP_MURPHY_SNAPPING_DOWN			58
#define IMG_SP_MURPHY_BORING				59
#define IMG_SP_MURPHY_BORING_1				60
#define IMG_SP_MURPHY_SLEEPING_LEFT			61
#define IMG_SP_MURPHY_SLEEPING_RIGHT			62
#define IMG_SP_MURPHY_DROPPING				63
#define IMG_SP_MURPHY_SHRINKING				64
#define IMG_SP_MURPHY_CLONE				65
#define IMG_SP_INFOTRON					66
#define IMG_SP_INFOTRON_EDITOR				67
#define IMG_SP_INFOTRON_MOVING_LEFT			68
#define IMG_SP_INFOTRON_MOVING_RIGHT			69
#define IMG_SP_INFOTRON_COLLECTING			70
#define IMG_SP_CHIP_SINGLE				71
#define IMG_SP_CHIP_LEFT				72
#define IMG_SP_CHIP_RIGHT				73
#define IMG_SP_CHIP_TOP					74
#define IMG_SP_CHIP_BOTTOM				75
#define IMG_SP_HARDWARE_GRAY				76
#define IMG_SP_HARDWARE_GREEN				77
#define IMG_SP_HARDWARE_BLUE				78
#define IMG_SP_HARDWARE_RED				79
#define IMG_SP_HARDWARE_YELLOW				80
#define IMG_SP_EXIT_CLOSED				81
#define IMG_SP_EXIT_OPENING				82
#define IMG_SP_EXIT_OPEN				83
#define IMG_SP_EXIT_CLOSING				84
#define IMG_SP_DISK_ORANGE				85
#define IMG_SP_DISK_YELLOW				86
#define IMG_SP_DISK_RED					87
#define IMG_SP_DISK_RED_COLLECTING			88
#define IMG_SP_DISK_RED_ACTIVE				89
#define IMG_SP_PORT_RIGHT				90
#define IMG_SP_PORT_DOWN				91
#define IMG_SP_PORT_LEFT				92
#define IMG_SP_PORT_UP					93
#define IMG_SP_PORT_HORIZONTAL				94
#define IMG_SP_PORT_VERTICAL				95
#define IMG_SP_PORT_ANY					96
#define IMG_SP_GRAVITY_PORT_RIGHT			97
#define IMG_SP_GRAVITY_PORT_RIGHT_EDITOR		98
#define IMG_SP_GRAVITY_PORT_DOWN			99
#define IMG_SP_GRAVITY_PORT_DOWN_EDITOR			100
#define IMG_SP_GRAVITY_PORT_LEFT			101
#define IMG_SP_GRAVITY_PORT_LEFT_EDITOR			102
#define IMG_SP_GRAVITY_PORT_UP				103
#define IMG_SP_GRAVITY_PORT_UP_EDITOR			104
#define IMG_SP_GRAVITY_ON_PORT_RIGHT			105
#define IMG_SP_GRAVITY_ON_PORT_RIGHT_EDITOR		106
#define IMG_SP_GRAVITY_ON_PORT_DOWN			107
#define IMG_SP_GRAVITY_ON_PORT_DOWN_EDITOR		108
#define IMG_SP_GRAVITY_ON_PORT_LEFT			109
#define IMG_SP_GRAVITY_ON_PORT_LEFT_EDITOR		110
#define IMG_SP_GRAVITY_ON_PORT_UP			111
#define IMG_SP_GRAVITY_ON_PORT_UP_EDITOR		112
#define IMG_SP_GRAVITY_OFF_PORT_RIGHT			113
#define IMG_SP_GRAVITY_OFF_PORT_RIGHT_EDITOR		114
#define IMG_SP_GRAVITY_OFF_PORT_DOWN			115
#define IMG_SP_GRAVITY_OFF_PORT_DOWN_EDITOR		116
#define IMG_SP_GRAVITY_OFF_PORT_LEFT			117
#define IMG_SP_GRAVITY_OFF_PORT_LEFT_EDITOR		118
#define IMG_SP_GRAVITY_OFF_PORT_UP			119
#define IMG_SP_GRAVITY_OFF_PORT_UP_EDITOR		120
#define IMG_SP_SNIKSNAK					121
#define IMG_SP_SNIKSNAK_LEFT				122
#define IMG_SP_SNIKSNAK_RIGHT				123
#define IMG_SP_SNIKSNAK_UP				124
#define IMG_SP_SNIKSNAK_DOWN				125
#define IMG_SP_SNIKSNAK_TURNING_FROM_LEFT_UP		126
#define IMG_SP_SNIKSNAK_TURNING_FROM_LEFT_DOWN		127
#define IMG_SP_SNIKSNAK_TURNING_FROM_RIGHT_UP		128
#define IMG_SP_SNIKSNAK_TURNING_FROM_RIGHT_DOWN		129
#define IMG_SP_SNIKSNAK_TURNING_FROM_UP_LEFT		130
#define IMG_SP_SNIKSNAK_TURNING_FROM_UP_RIGHT		131
#define IMG_SP_SNIKSNAK_TURNING_FROM_DOWN_LEFT		132
#define IMG_SP_SNIKSNAK_TURNING_FROM_DOWN_RIGHT		133
#define IMG_SP_ELECTRON					134
#define IMG_SP_ELECTRON_EDITOR				135
#define IMG_SP_ELECTRON_EXPLODING			136
#define IMG_SP_TERMINAL					137
#define IMG_SP_TERMINAL_EDITOR				138
#define IMG_SP_TERMINAL_ACTIVE				139
#define IMG_SP_BUGGY_BASE				140
#define IMG_SP_BUGGY_BASE_EDITOR			141
#define IMG_SP_BUGGY_BASE_ACTIVATING			142
#define IMG_SP_BUGGY_BASE_ACTIVE			143
#define IMG_SP_HARDWARE_BASE_1				144
#define IMG_SP_HARDWARE_BASE_2				145
#define IMG_SP_HARDWARE_BASE_3				146
#define IMG_SP_HARDWARE_BASE_4				147
#define IMG_SP_HARDWARE_BASE_5				148
#define IMG_SP_HARDWARE_BASE_6				149
#define IMG_SOKOBAN_OBJECT				150
#define IMG_SOKOBAN_OBJECT_EDITOR			151
#define IMG_SOKOBAN_FIELD_EMPTY				152
#define IMG_SOKOBAN_FIELD_FULL				153
#define IMG_SOKOBAN_FIELD_PLAYER			154
#define IMG_SOKOBAN_FIELD_PLAYER_EDITOR			155
#define IMG_EMPTY_SPACE					156
#define IMG_SAND					157
#define IMG_SAND_CRUMBLED				158
#define IMG_SAND_DIGGING_LEFT				159
#define IMG_SAND_DIGGING_RIGHT				160
#define IMG_SAND_DIGGING_UP				161
#define IMG_SAND_DIGGING_DOWN				162
#define IMG_SAND_DIGGING_LEFT_CRUMBLED			163
#define IMG_SAND_DIGGING_RIGHT_CRUMBLED			164
#define IMG_SAND_DIGGING_UP_CRUMBLED			165
#define IMG_SAND_DIGGING_DOWN_CRUMBLED			166
#define IMG_WALL					167
#define IMG_WALL_SLIPPERY				168
#define IMG_STEELWALL					169
#define IMG_ROCK					170
#define IMG_ROCK_MOVING_LEFT				171
#define IMG_ROCK_MOVING_RIGHT				172
#define IMG_ROCK_PUSHING_LEFT				173
#define IMG_ROCK_PUSHING_RIGHT				174
#define IMG_EMERALD					175
#define IMG_EMERALD_MOVING				176
#define IMG_EMERALD_FALLING				177
#define IMG_EMERALD_COLLECTING				178
#define IMG_DIAMOND					179
#define IMG_DIAMOND_MOVING				180
#define IMG_DIAMOND_FALLING				181
#define IMG_DIAMOND_COLLECTING				182
#define IMG_BOMB					183
#define IMG_NUT						184
#define IMG_NUT_BREAKING				185
#define IMG_DYNAMITE					186
#define IMG_DYNAMITE_EDITOR				187
#define IMG_DYNAMITE_ACTIVE				188
#define IMG_DYNAMITE_ACTIVE_EDITOR			189
#define IMG_EM_DYNAMITE					190
#define IMG_EM_DYNAMITE_ACTIVE				191
#define IMG_EM_DYNAMITE_ACTIVE_EDITOR			192
#define IMG_WALL_EMERALD				193
#define IMG_WALL_DIAMOND				194
#define IMG_BUG						195
#define IMG_BUG_RIGHT					196
#define IMG_BUG_UP					197
#define IMG_BUG_LEFT					198
#define IMG_BUG_DOWN					199
#define IMG_BUG_MOVING_RIGHT				200
#define IMG_BUG_MOVING_UP				201
#define IMG_BUG_MOVING_LEFT				202
#define IMG_BUG_MOVING_DOWN				203
#define IMG_BUG_TURNING_FROM_RIGHT_UP			204
#define IMG_BUG_TURNING_FROM_UP_LEFT			205
#define IMG_BUG_TURNING_FROM_LEFT_DOWN			206
#define IMG_BUG_TURNING_FROM_DOWN_RIGHT			207
#define IMG_BUG_TURNING_FROM_RIGHT_DOWN			208
#define IMG_BUG_TURNING_FROM_UP_RIGHT			209
#define IMG_BUG_TURNING_FROM_LEFT_UP			210
#define IMG_BUG_TURNING_FROM_DOWN_LEFT			211
#define IMG_SPACESHIP					212
#define IMG_SPACESHIP_RIGHT				213
#define IMG_SPACESHIP_UP				214
#define IMG_SPACESHIP_LEFT				215
#define IMG_SPACESHIP_DOWN				216
#define IMG_SPACESHIP_MOVING_RIGHT			217
#define IMG_SPACESHIP_MOVING_UP				218
#define IMG_SPACESHIP_MOVING_LEFT			219
#define IMG_SPACESHIP_MOVING_DOWN			220
#define IMG_SPACESHIP_TURNING_FROM_RIGHT_UP		221
#define IMG_SPACESHIP_TURNING_FROM_UP_LEFT		222
#define IMG_SPACESHIP_TURNING_FROM_LEFT_DOWN		223
#define IMG_SPACESHIP_TURNING_FROM_DOWN_RIGHT		224
#define IMG_SPACESHIP_TURNING_FROM_RIGHT_DOWN		225
#define IMG_SPACESHIP_TURNING_FROM_UP_RIGHT		226
#define IMG_SPACESHIP_TURNING_FROM_LEFT_UP		227
#define IMG_SPACESHIP_TURNING_FROM_DOWN_LEFT		228
#define IMG_YAMYAM					229
#define IMG_YAMYAM_LEFT					230
#define IMG_YAMYAM_LEFT_EDITOR				231
#define IMG_YAMYAM_RIGHT				232
#define IMG_YAMYAM_RIGHT_EDITOR				233
#define IMG_YAMYAM_UP					234
#define IMG_YAMYAM_UP_EDITOR				235
#define IMG_YAMYAM_DOWN					236
#define IMG_YAMYAM_DOWN_EDITOR				237
#define IMG_YAMYAM_MOVING				238
#define IMG_ROBOT					239
#define IMG_ROBOT_MOVING				240
#define IMG_ROBOT_WHEEL					241
#define IMG_ROBOT_WHEEL_ACTIVE				242
#define IMG_MAGIC_WALL					243
#define IMG_MAGIC_WALL_ACTIVE				244
#define IMG_MAGIC_WALL_FILLING				245
#define IMG_MAGIC_WALL_FULL				246
#define IMG_MAGIC_WALL_EMPTYING				247
#define IMG_MAGIC_WALL_DEAD				248
#define IMG_DC_MAGIC_WALL				249
#define IMG_DC_MAGIC_WALL_ACTIVE			250
#define IMG_DC_MAGIC_WALL_FILLING			251
#define IMG_DC_MAGIC_WALL_FULL				252
#define IMG_DC_MAGIC_WALL_EMPTYING			253
#define IMG_DC_MAGIC_WALL_DEAD				254
#define IMG_QUICKSAND_EMPTY				255
#define IMG_QUICKSAND_FILLING				256
#define IMG_QUICKSAND_FULL				257
#define IMG_QUICKSAND_FULL_EDITOR			258
#define IMG_QUICKSAND_EMPTYING				259
#define IMG_QUICKSAND_FAST_EMPTY			260
#define IMG_QUICKSAND_FAST_FILLING			261
#define IMG_QUICKSAND_FAST_FULL				262
#define IMG_QUICKSAND_FAST_FULL_EDITOR			263
#define IMG_QUICKSAND_FAST_EMPTYING			264
#define IMG_ACID_POOL_TOPLEFT				265
#define IMG_ACID_POOL_TOPRIGHT				266
#define IMG_ACID_POOL_BOTTOMLEFT			267
#define IMG_ACID_POOL_BOTTOM				268
#define IMG_ACID_POOL_BOTTOMRIGHT			269
#define IMG_ACID					270
#define IMG_ACID_SPLASH_LEFT				271
#define IMG_ACID_SPLASH_RIGHT				272
#define IMG_AMOEBA_DROP					273
#define IMG_AMOEBA_GROWING				274
#define IMG_AMOEBA_SHRINKING				275
#define IMG_AMOEBA_WET					276
#define IMG_AMOEBA_WET_EDITOR				277
#define IMG_AMOEBA_DROPPING				278
#define IMG_AMOEBA_DRY					279
#define IMG_AMOEBA_FULL					280
#define IMG_AMOEBA_FULL_EDITOR				281
#define IMG_AMOEBA_DEAD					282
#define IMG_AMOEBA_DEAD_EDITOR				283
#define IMG_EM_KEY_1					284
#define IMG_EM_KEY_2					285
#define IMG_EM_KEY_3					286
#define IMG_EM_KEY_4					287
#define IMG_DC_KEY_WHITE				288
#define IMG_EM_GATE_1					289
#define IMG_EM_GATE_2					290
#define IMG_EM_GATE_3					291
#define IMG_EM_GATE_4					292
#define IMG_DC_GATE_WHITE				293
#define IMG_EM_GATE_1_GRAY				294
#define IMG_EM_GATE_1_GRAY_EDITOR			295
#define IMG_EM_GATE_1_GRAY_ACTIVE			296
#define IMG_EM_GATE_2_GRAY				297
#define IMG_EM_GATE_2_GRAY_EDITOR			298
#define IMG_EM_GATE_2_GRAY_ACTIVE			299
#define IMG_EM_GATE_3_GRAY				300
#define IMG_EM_GATE_3_GRAY_EDITOR			301
#define IMG_EM_GATE_3_GRAY_ACTIVE			302
#define IMG_EM_GATE_4_GRAY				303
#define IMG_EM_GATE_4_GRAY_EDITOR			304
#define IMG_EM_GATE_4_GRAY_ACTIVE			305
#define IMG_DC_GATE_WHITE_GRAY				306
#define IMG_DC_GATE_WHITE_GRAY_EDITOR			307
#define IMG_DC_GATE_WHITE_GRAY_ACTIVE			308
#define IMG_DC_GATE_FAKE_GRAY				309
#define IMG_EXIT_CLOSED					310
#define IMG_EXIT_OPENING				311
#define IMG_EXIT_OPEN					312
#define IMG_EXIT_CLOSING				313
#define IMG_STEEL_EXIT_CLOSED				314
#define IMG_STEEL_EXIT_OPENING				315
#define IMG_STEEL_EXIT_OPEN				316
#define IMG_STEEL_EXIT_CLOSING				317
#define IMG_EM_EXIT_CLOSED				318
#define IMG_EM_EXIT_OPENING				319
#define IMG_EM_EXIT_OPEN				320
#define IMG_EM_EXIT_CLOSING				321
#define IMG_EM_STEEL_EXIT_CLOSED			322
#define IMG_EM_STEEL_EXIT_OPENING			323
#define IMG_EM_STEEL_EXIT_OPEN				324
#define IMG_EM_STEEL_EXIT_CLOSING			325
#define IMG_BALLOON					326
#define IMG_BALLOON_MOVING				327
#define IMG_BALLOON_PUSHING				328
#define IMG_BALLOON_SWITCH_LEFT				329
#define IMG_BALLOON_SWITCH_RIGHT			330
#define IMG_BALLOON_SWITCH_UP				331
#define IMG_BALLOON_SWITCH_DOWN				332
#define IMG_BALLOON_SWITCH_ANY				333
#define IMG_BALLOON_SWITCH_NONE				334
#define IMG_SPRING					335
#define IMG_EMC_STEELWALL_1				336
#define IMG_EMC_STEELWALL_2				337
#define IMG_EMC_STEELWALL_3				338
#define IMG_EMC_STEELWALL_4				339
#define IMG_EMC_WALL_1					340
#define IMG_EMC_WALL_2					341
#define IMG_EMC_WALL_3					342
#define IMG_EMC_WALL_4					343
#define IMG_EMC_WALL_5					344
#define IMG_EMC_WALL_6					345
#define IMG_EMC_WALL_7					346
#define IMG_EMC_WALL_8					347
#define IMG_INVISIBLE_STEELWALL				348
#define IMG_INVISIBLE_STEELWALL_EDITOR			349
#define IMG_INVISIBLE_STEELWALL_ACTIVE			350
#define IMG_INVISIBLE_WALL				351
#define IMG_INVISIBLE_WALL_EDITOR			352
#define IMG_INVISIBLE_WALL_ACTIVE			353
#define IMG_INVISIBLE_SAND				354
#define IMG_INVISIBLE_SAND_EDITOR			355
#define IMG_INVISIBLE_SAND_ACTIVE			356
#define IMG_INVISIBLE_SAND_ACTIVE_CRUMBLED		357
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_LEFT		358
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_RIGHT		359
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_UP		360
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_DOWN		361
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_LEFT_CRUMBLED	362
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_RIGHT_CRUMBLED	363
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_UP_CRUMBLED	364
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_DOWN_CRUMBLED	365
#define IMG_CONVEYOR_BELT_1_MIDDLE			366
#define IMG_CONVEYOR_BELT_1_MIDDLE_ACTIVE		367
#define IMG_CONVEYOR_BELT_1_LEFT			368
#define IMG_CONVEYOR_BELT_1_LEFT_ACTIVE			369
#define IMG_CONVEYOR_BELT_1_RIGHT			370
#define IMG_CONVEYOR_BELT_1_RIGHT_ACTIVE		371
#define IMG_CONVEYOR_BELT_1_SWITCH_LEFT			372
#define IMG_CONVEYOR_BELT_1_SWITCH_MIDDLE		373
#define IMG_CONVEYOR_BELT_1_SWITCH_RIGHT		374
#define IMG_CONVEYOR_BELT_2_MIDDLE			375
#define IMG_CONVEYOR_BELT_2_MIDDLE_ACTIVE		376
#define IMG_CONVEYOR_BELT_2_LEFT			377
#define IMG_CONVEYOR_BELT_2_LEFT_ACTIVE			378
#define IMG_CONVEYOR_BELT_2_RIGHT			379
#define IMG_CONVEYOR_BELT_2_RIGHT_ACTIVE		380
#define IMG_CONVEYOR_BELT_2_SWITCH_LEFT			381
#define IMG_CONVEYOR_BELT_2_SWITCH_MIDDLE		382
#define IMG_CONVEYOR_BELT_2_SWITCH_RIGHT		383
#define IMG_CONVEYOR_BELT_3_MIDDLE			384
#define IMG_CONVEYOR_BELT_3_MIDDLE_ACTIVE		385
#define IMG_CONVEYOR_BELT_3_LEFT			386
#define IMG_CONVEYOR_BELT_3_LEFT_ACTIVE			387
#define IMG_CONVEYOR_BELT_3_RIGHT			388
#define IMG_CONVEYOR_BELT_3_RIGHT_ACTIVE		389
#define IMG_CONVEYOR_BELT_3_SWITCH_LEFT			390
#define IMG_CONVEYOR_BELT_3_SWITCH_MIDDLE		391
#define IMG_CONVEYOR_BELT_3_SWITCH_RIGHT		392
#define IMG_CONVEYOR_BELT_4_MIDDLE			393
#define IMG_CONVEYOR_BELT_4_MIDDLE_ACTIVE		394
#define IMG_CONVEYOR_BELT_4_LEFT			395
#define IMG_CONVEYOR_BELT_4_LEFT_ACTIVE			396
#define IMG_CONVEYOR_BELT_4_RIGHT			397
#define IMG_CONVEYOR_BELT_4_RIGHT_ACTIVE		398
#define IMG_CONVEYOR_BELT_4_SWITCH_LEFT			399
#define IMG_CONVEYOR_BELT_4_SWITCH_MIDDLE		400
#define IMG_CONVEYOR_BELT_4_SWITCH_RIGHT		401
#define IMG_SWITCHGATE_SWITCH_UP			402
#define IMG_SWITCHGATE_SWITCH_DOWN			403
#define IMG_DC_SWITCHGATE_SWITCH_UP			404
#define IMG_DC_SWITCHGATE_SWITCH_DOWN			405
#define IMG_LIGHT_SWITCH				406
#define IMG_LIGHT_SWITCH_ACTIVE				407
#define IMG_TIMEGATE_SWITCH				408
#define IMG_TIMEGATE_SWITCH_ACTIVE			409
#define IMG_DC_TIMEGATE_SWITCH				410
#define IMG_DC_TIMEGATE_SWITCH_ACTIVE			411
#define IMG_ENVELOPE_1					412
#define IMG_ENVELOPE_1_COLLECTING			413
#define IMG_ENVELOPE_2					414
#define IMG_ENVELOPE_2_COLLECTING			415
#define IMG_ENVELOPE_3					416
#define IMG_ENVELOPE_3_COLLECTING			417
#define IMG_ENVELOPE_4					418
#define IMG_ENVELOPE_4_COLLECTING			419
#define IMG_SIGN_RADIOACTIVITY				420
#define IMG_SIGN_GIVE_WAY				421
#define IMG_SIGN_NO_ENTRY				422
#define IMG_SIGN_EMERGENCY_EXIT				423
#define IMG_SIGN_YIN_YANG				424
#define IMG_SIGN_EXCLAMATION				425
#define IMG_SIGN_STOP					426
#define IMG_SIGN_PARKING				427
#define IMG_SIGN_WHEELCHAIR				428
#define IMG_SIGN_ENTRY_FORBIDDEN			429
#define IMG_SPERMS					430
#define IMG_BULLET					431
#define IMG_HEART					432
#define IMG_CROSS					433
#define IMG_FRANKIE					434
#define IMG_SIGN_SPERMS					435
#define IMG_SIGN_BULLET					436
#define IMG_SIGN_HEART					437
#define IMG_SIGN_CROSS					438
#define IMG_SIGN_FRANKIE				439
#define IMG_LANDMINE					440
#define IMG_DC_LANDMINE					441
#define IMG_STEELWALL_SLIPPERY				442
#define IMG_EXTRA_TIME					443
#define IMG_SHIELD_NORMAL				444
#define IMG_SHIELD_NORMAL_ACTIVE			445
#define IMG_SHIELD_DEADLY				446
#define IMG_SHIELD_DEADLY_ACTIVE			447
#define IMG_SWITCHGATE_CLOSED				448
#define IMG_SWITCHGATE_OPENING				449
#define IMG_SWITCHGATE_OPEN				450
#define IMG_SWITCHGATE_CLOSING				451
#define IMG_TIMEGATE_CLOSED				452
#define IMG_TIMEGATE_OPENING				453
#define IMG_TIMEGATE_OPEN				454
#define IMG_TIMEGATE_CLOSING				455
#define IMG_PEARL					456
#define IMG_PEARL_BREAKING				457
#define IMG_CRYSTAL					458
#define IMG_WALL_PEARL					459
#define IMG_WALL_CRYSTAL				460
#define IMG_DC_STEELWALL_1_LEFT				461
#define IMG_DC_STEELWALL_1_RIGHT			462
#define IMG_DC_STEELWALL_1_TOP				463
#define IMG_DC_STEELWALL_1_BOTTOM			464
#define IMG_DC_STEELWALL_1_HORIZONTAL			465
#define IMG_DC_STEELWALL_1_VERTICAL			466
#define IMG_DC_STEELWALL_1_TOPLEFT			467
#define IMG_DC_STEELWALL_1_TOPRIGHT			468
#define IMG_DC_STEELWALL_1_BOTTOMLEFT			469
#define IMG_DC_STEELWALL_1_BOTTOMRIGHT			470
#define IMG_DC_STEELWALL_1_TOPLEFT_2			471
#define IMG_DC_STEELWALL_1_TOPRIGHT_2			472
#define IMG_DC_STEELWALL_1_BOTTOMLEFT_2			473
#define IMG_DC_STEELWALL_1_BOTTOMRIGHT_2		474
#define IMG_DC_STEELWALL_2_LEFT				475
#define IMG_DC_STEELWALL_2_RIGHT			476
#define IMG_DC_STEELWALL_2_TOP				477
#define IMG_DC_STEELWALL_2_BOTTOM			478
#define IMG_DC_STEELWALL_2_HORIZONTAL			479
#define IMG_DC_STEELWALL_2_VERTICAL			480
#define IMG_DC_STEELWALL_2_MIDDLE			481
#define IMG_DC_STEELWALL_2_SINGLE			482
#define IMG_TUBE_RIGHT_DOWN				483
#define IMG_TUBE_HORIZONTAL_DOWN			484
#define IMG_TUBE_LEFT_DOWN				485
#define IMG_TUBE_HORIZONTAL				486
#define IMG_TUBE_VERTICAL_RIGHT				487
#define IMG_TUBE_ANY					488
#define IMG_TUBE_VERTICAL_LEFT				489
#define IMG_TUBE_VERTICAL				490
#define IMG_TUBE_RIGHT_UP				491
#define IMG_TUBE_HORIZONTAL_UP				492
#define IMG_TUBE_LEFT_UP				493
#define IMG_TRAP					494
#define IMG_TRAP_ACTIVE					495
#define IMG_DX_SUPABOMB					496
#define IMG_KEY_1					497
#define IMG_KEY_1_EDITOR				498
#define IMG_KEY_2					499
#define IMG_KEY_2_EDITOR				500
#define IMG_KEY_3					501
#define IMG_KEY_3_EDITOR				502
#define IMG_KEY_4					503
#define IMG_KEY_4_EDITOR				504
#define IMG_GATE_1					505
#define IMG_GATE_2					506
#define IMG_GATE_3					507
#define IMG_GATE_4					508
#define IMG_GATE_1_GRAY					509
#define IMG_GATE_1_GRAY_EDITOR				510
#define IMG_GATE_1_GRAY_ACTIVE				511
#define IMG_GATE_2_GRAY					512
#define IMG_GATE_2_GRAY_EDITOR				513
#define IMG_GATE_2_GRAY_ACTIVE				514
#define IMG_GATE_3_GRAY					515
#define IMG_GATE_3_GRAY_EDITOR				516
#define IMG_GATE_3_GRAY_ACTIVE				517
#define IMG_GATE_4_GRAY					518
#define IMG_GATE_4_GRAY_EDITOR				519
#define IMG_GATE_4_GRAY_ACTIVE				520
#define IMG_GAME_OF_LIFE				521
#define IMG_BIOMAZE					522
#define IMG_PACMAN					523
#define IMG_PACMAN_RIGHT				524
#define IMG_PACMAN_UP					525
#define IMG_PACMAN_LEFT					526
#define IMG_PACMAN_DOWN					527
#define IMG_PACMAN_TURNING_FROM_RIGHT			528
#define IMG_PACMAN_TURNING_FROM_UP			529
#define IMG_PACMAN_TURNING_FROM_LEFT			530
#define IMG_PACMAN_TURNING_FROM_DOWN			531
#define IMG_LAMP					532
#define IMG_LAMP_EDITOR					533
#define IMG_LAMP_ACTIVE					534
#define IMG_TIME_ORB_FULL				535
#define IMG_TIME_ORB_EMPTY				536
#define IMG_EMERALD_YELLOW				537
#define IMG_EMERALD_YELLOW_MOVING			538
#define IMG_EMERALD_YELLOW_FALLING			539
#define IMG_EMERALD_RED					540
#define IMG_EMERALD_RED_MOVING				541
#define IMG_EMERALD_RED_FALLING				542
#define IMG_EMERALD_PURPLE				543
#define IMG_EMERALD_PURPLE_MOVING			544
#define IMG_EMERALD_PURPLE_FALLING			545
#define IMG_WALL_EMERALD_YELLOW				546
#define IMG_WALL_EMERALD_RED				547
#define IMG_WALL_EMERALD_PURPLE				548
#define IMG_WALL_BD_DIAMOND				549
#define IMG_EXPANDABLE_WALL				550
#define IMG_EXPANDABLE_WALL_HORIZONTAL			551
#define IMG_EXPANDABLE_WALL_HORIZONTAL_EDITOR		552
#define IMG_EXPANDABLE_WALL_VERTICAL			553
#define IMG_EXPANDABLE_WALL_VERTICAL_EDITOR		554
#define IMG_EXPANDABLE_WALL_ANY				555
#define IMG_EXPANDABLE_WALL_ANY_EDITOR			556
#define IMG_EXPANDABLE_STEELWALL_HORIZONTAL		557
#define IMG_EXPANDABLE_STEELWALL_HORIZONTAL_EDITOR	558
#define IMG_EXPANDABLE_STEELWALL_VERTICAL		559
#define IMG_EXPANDABLE_STEELWALL_VERTICAL_EDITOR	560
#define IMG_EXPANDABLE_STEELWALL_ANY			561
#define IMG_EXPANDABLE_STEELWALL_ANY_EDITOR		562
#define IMG_BD_EXPANDABLE_WALL				563
#define IMG_BD_EXPANDABLE_WALL_EDITOR			564
#define IMG_EXPANDABLE_WALL_GROWING_LEFT		565
#define IMG_EXPANDABLE_WALL_GROWING_RIGHT		566
#define IMG_EXPANDABLE_WALL_GROWING_UP			567
#define IMG_EXPANDABLE_WALL_GROWING_DOWN		568
#define IMG_EXPANDABLE_STEELWALL_GROWING_LEFT		569
#define IMG_EXPANDABLE_STEELWALL_GROWING_RIGHT		570
#define IMG_EXPANDABLE_STEELWALL_GROWING_UP		571
#define IMG_EXPANDABLE_STEELWALL_GROWING_DOWN		572
#define IMG_BLACK_ORB					573
#define IMG_SPEED_PILL					574
#define IMG_DARK_YAMYAM					575
#define IMG_DYNABOMB					576
#define IMG_DYNABOMB_ACTIVE				577
#define IMG_DYNABOMB_PLAYER_1				578
#define IMG_DYNABOMB_PLAYER_1_ACTIVE			579
#define IMG_DYNABOMB_PLAYER_2				580
#define IMG_DYNABOMB_PLAYER_2_ACTIVE			581
#define IMG_DYNABOMB_PLAYER_3				582
#define IMG_DYNABOMB_PLAYER_3_ACTIVE			583
#define IMG_DYNABOMB_PLAYER_4				584
#define IMG_DYNABOMB_PLAYER_4_ACTIVE			585
#define IMG_DYNABOMB_INCREASE_NUMBER			586
#define IMG_DYNABOMB_INCREASE_SIZE			587
#define IMG_DYNABOMB_INCREASE_POWER			588
#define IMG_PIG						589
#define IMG_PIG_DOWN					590
#define IMG_PIG_UP					591
#define IMG_PIG_LEFT					592
#define IMG_PIG_RIGHT					593
#define IMG_PIG_MOVING_DOWN				594
#define IMG_PIG_MOVING_UP				595
#define IMG_PIG_MOVING_LEFT				596
#define IMG_PIG_MOVING_RIGHT				597
#define IMG_PIG_DIGGING_DOWN				598
#define IMG_PIG_DIGGING_UP				599
#define IMG_PIG_DIGGING_LEFT				600
#define IMG_PIG_DIGGING_RIGHT				601
#define IMG_DRAGON					602
#define IMG_DRAGON_DOWN					603
#define IMG_DRAGON_UP					604
#define IMG_DRAGON_LEFT					605
#define IMG_DRAGON_RIGHT				606
#define IMG_DRAGON_MOVING_DOWN				607
#define IMG_DRAGON_MOVING_UP				608
#define IMG_DRAGON_MOVING_LEFT				609
#define IMG_DRAGON_MOVING_RIGHT				610
#define IMG_DRAGON_ATTACKING_DOWN			611
#define IMG_DRAGON_ATTACKING_UP				612
#define IMG_DRAGON_ATTACKING_LEFT			613
#define IMG_DRAGON_ATTACKING_RIGHT			614
#define IMG_MOLE					615
#define IMG_MOLE_DOWN					616
#define IMG_MOLE_UP					617
#define IMG_MOLE_LEFT					618
#define IMG_MOLE_RIGHT					619
#define IMG_MOLE_MOVING_DOWN				620
#define IMG_MOLE_MOVING_UP				621
#define IMG_MOLE_MOVING_LEFT				622
#define IMG_MOLE_MOVING_RIGHT				623
#define IMG_MOLE_DIGGING_DOWN				624
#define IMG_MOLE_DIGGING_UP				625
#define IMG_MOLE_DIGGING_LEFT				626
#define IMG_MOLE_DIGGING_RIGHT				627
#define IMG_PENGUIN					628
#define IMG_PENGUIN_EDITOR				629
#define IMG_PENGUIN_DOWN				630
#define IMG_PENGUIN_UP					631
#define IMG_PENGUIN_LEFT				632
#define IMG_PENGUIN_RIGHT				633
#define IMG_PENGUIN_MOVING_DOWN				634
#define IMG_PENGUIN_MOVING_UP				635
#define IMG_PENGUIN_MOVING_LEFT				636
#define IMG_PENGUIN_MOVING_RIGHT			637
#define IMG_SATELLITE					638
#define IMG_FLAMES_1_LEFT				639
#define IMG_FLAMES_2_LEFT				640
#define IMG_FLAMES_3_LEFT				641
#define IMG_FLAMES_1_RIGHT				642
#define IMG_FLAMES_2_RIGHT				643
#define IMG_FLAMES_3_RIGHT				644
#define IMG_FLAMES_1_UP					645
#define IMG_FLAMES_2_UP					646
#define IMG_FLAMES_3_UP					647
#define IMG_FLAMES_1_DOWN				648
#define IMG_FLAMES_2_DOWN				649
#define IMG_FLAMES_3_DOWN				650
#define IMG_STONEBLOCK					651
#define IMG_PLAYER_1					652
#define IMG_PLAYER_1_EDITOR				653
#define IMG_PLAYER_1_DOWN				654
#define IMG_PLAYER_1_UP					655
#define IMG_PLAYER_1_LEFT				656
#define IMG_PLAYER_1_RIGHT				657
#define IMG_PLAYER_1_MOVING_DOWN			658
#define IMG_PLAYER_1_MOVING_UP				659
#define IMG_PLAYER_1_MOVING_LEFT			660
#define IMG_PLAYER_1_MOVING_RIGHT			661
#define IMG_PLAYER_1_DIGGING_DOWN			662
#define IMG_PLAYER_1_DIGGING_UP				663
#define IMG_PLAYER_1_DIGGING_LEFT			664
#define IMG_PLAYER_1_DIGGING_RIGHT			665
#define IMG_PLAYER_1_COLLECTING_DOWN			666
#define IMG_PLAYER_1_COLLECTING_UP			667
#define IMG_PLAYER_1_COLLECTING_LEFT			668
#define IMG_PLAYER_1_COLLECTING_RIGHT			669
#define IMG_PLAYER_1_PUSHING_DOWN			670
#define IMG_PLAYER_1_PUSHING_UP				671
#define IMG_PLAYER_1_PUSHING_LEFT			672
#define IMG_PLAYER_1_PUSHING_RIGHT			673
#define IMG_PLAYER_1_SNAPPING_DOWN			674
#define IMG_PLAYER_1_SNAPPING_UP			675
#define IMG_PLAYER_1_SNAPPING_LEFT			676
#define IMG_PLAYER_1_SNAPPING_RIGHT			677
#define IMG_PLAYER_2					678
#define IMG_PLAYER_2_EDITOR				679
#define IMG_PLAYER_2_DOWN				680
#define IMG_PLAYER_2_UP					681
#define IMG_PLAYER_2_LEFT				682
#define IMG_PLAYER_2_RIGHT				683
#define IMG_PLAYER_2_MOVING_DOWN			684
#define IMG_PLAYER_2_MOVING_UP				685
#define IMG_PLAYER_2_MOVING_LEFT			686
#define IMG_PLAYER_2_MOVING_RIGHT			687
#define IMG_PLAYER_2_DIGGING_DOWN			688
#define IMG_PLAYER_2_DIGGING_UP				689
#define IMG_PLAYER_2_DIGGING_LEFT			690
#define IMG_PLAYER_2_DIGGING_RIGHT			691
#define IMG_PLAYER_2_COLLECTING_DOWN			692
#define IMG_PLAYER_2_COLLECTING_UP			693
#define IMG_PLAYER_2_COLLECTING_LEFT			694
#define IMG_PLAYER_2_COLLECTING_RIGHT			695
#define IMG_PLAYER_2_PUSHING_DOWN			696
#define IMG_PLAYER_2_PUSHING_UP				697
#define IMG_PLAYER_2_PUSHING_LEFT			698
#define IMG_PLAYER_2_PUSHING_RIGHT			699
#define IMG_PLAYER_2_SNAPPING_DOWN			700
#define IMG_PLAYER_2_SNAPPING_UP			701
#define IMG_PLAYER_2_SNAPPING_LEFT			702
#define IMG_PLAYER_2_SNAPPING_RIGHT			703
#define IMG_PLAYER_3					704
#define IMG_PLAYER_3_EDITOR				705
#define IMG_PLAYER_3_DOWN				706
#define IMG_PLAYER_3_UP					707
#define IMG_PLAYER_3_LEFT				708
#define IMG_PLAYER_3_RIGHT				709
#define IMG_PLAYER_3_MOVING_DOWN			710
#define IMG_PLAYER_3_MOVING_UP				711
#define IMG_PLAYER_3_MOVING_LEFT			712
#define IMG_PLAYER_3_MOVING_RIGHT			713
#define IMG_PLAYER_3_DIGGING_DOWN			714
#define IMG_PLAYER_3_DIGGING_UP				715
#define IMG_PLAYER_3_DIGGING_LEFT			716
#define IMG_PLAYER_3_DIGGING_RIGHT			717
#define IMG_PLAYER_3_COLLECTING_DOWN			718
#define IMG_PLAYER_3_COLLECTING_UP			719
#define IMG_PLAYER_3_COLLECTING_LEFT			720
#define IMG_PLAYER_3_COLLECTING_RIGHT			721
#define IMG_PLAYER_3_PUSHING_DOWN			722
#define IMG_PLAYER_3_PUSHING_UP				723
#define IMG_PLAYER_3_PUSHING_LEFT			724
#define IMG_PLAYER_3_PUSHING_RIGHT			725
#define IMG_PLAYER_3_SNAPPING_DOWN			726
#define IMG_PLAYER_3_SNAPPING_UP			727
#define IMG_PLAYER_3_SNAPPING_LEFT			728
#define IMG_PLAYER_3_SNAPPING_RIGHT			729
#define IMG_PLAYER_4					730
#define IMG_PLAYER_4_EDITOR				731
#define IMG_PLAYER_4_DOWN				732
#define IMG_PLAYER_4_UP					733
#define IMG_PLAYER_4_LEFT				734
#define IMG_PLAYER_4_RIGHT				735
#define IMG_PLAYER_4_MOVING_DOWN			736
#define IMG_PLAYER_4_MOVING_UP				737
#define IMG_PLAYER_4_MOVING_LEFT			738
#define IMG_PLAYER_4_MOVING_RIGHT			739
#define IMG_PLAYER_4_DIGGING_DOWN			740
#define IMG_PLAYER_4_DIGGING_UP				741
#define IMG_PLAYER_4_DIGGING_LEFT			742
#define IMG_PLAYER_4_DIGGING_RIGHT			743
#define IMG_PLAYER_4_COLLECTING_DOWN			744
#define IMG_PLAYER_4_COLLECTING_UP			745
#define IMG_PLAYER_4_COLLECTING_LEFT			746
#define IMG_PLAYER_4_COLLECTING_RIGHT			747
#define IMG_PLAYER_4_PUSHING_DOWN			748
#define IMG_PLAYER_4_PUSHING_UP				749
#define IMG_PLAYER_4_PUSHING_LEFT			750
#define IMG_PLAYER_4_PUSHING_RIGHT			751
#define IMG_PLAYER_4_SNAPPING_DOWN			752
#define IMG_PLAYER_4_SNAPPING_UP			753
#define IMG_PLAYER_4_SNAPPING_LEFT			754
#define IMG_PLAYER_4_SNAPPING_RIGHT			755
#define IMG_DEFAULT_EXPLODING				756
#define IMG_TWINKLE_BLUE				757
#define IMG_TWINKLE_WHITE				758
#define IMG_STEELWALL_TOPLEFT				759
#define IMG_STEELWALL_TOPRIGHT				760
#define IMG_STEELWALL_BOTTOMLEFT			761
#define IMG_STEELWALL_BOTTOMRIGHT			762
#define IMG_STEELWALL_HORIZONTAL			763
#define IMG_STEELWALL_VERTICAL				764
#define IMG_STEELWALL_TOPLEFT_EDITOR			765
#define IMG_STEELWALL_TOPRIGHT_EDITOR			766
#define IMG_STEELWALL_BOTTOMLEFT_EDITOR			767
#define IMG_STEELWALL_BOTTOMRIGHT_EDITOR		768
#define IMG_STEELWALL_HORIZONTAL_EDITOR			769
#define IMG_STEELWALL_VERTICAL_EDITOR			770
#define IMG_INVISIBLE_STEELWALL_TOPLEFT			771
#define IMG_INVISIBLE_STEELWALL_TOPRIGHT		772
#define IMG_INVISIBLE_STEELWALL_BOTTOMLEFT		773
#define IMG_INVISIBLE_STEELWALL_BOTTOMRIGHT		774
#define IMG_INVISIBLE_STEELWALL_HORIZONTAL		775
#define IMG_INVISIBLE_STEELWALL_VERTICAL		776
#define IMG_INVISIBLE_STEELWALL_TOPLEFT_EDITOR		777
#define IMG_INVISIBLE_STEELWALL_TOPRIGHT_EDITOR		778
#define IMG_INVISIBLE_STEELWALL_BOTTOMLEFT_EDITOR	779
#define IMG_INVISIBLE_STEELWALL_BOTTOMRIGHT_EDITOR	780
#define IMG_INVISIBLE_STEELWALL_HORIZONTAL_EDITOR	781
#define IMG_INVISIBLE_STEELWALL_VERTICAL_EDITOR		782
#define IMG_ARROW_LEFT					783
#define IMG_ARROW_RIGHT					784
#define IMG_ARROW_UP					785
#define IMG_ARROW_DOWN					786
#define IMG_UNKNOWN					787
#define IMG_TRIGGER_ELEMENT				788
#define IMG_TRIGGER_PLAYER				789
#define IMG_TRIGGER_CE_VALUE				790
#define IMG_TRIGGER_CE_SCORE				791
#define IMG_CURRENT_CE_VALUE				792
#define IMG_CURRENT_CE_SCORE				793
#define IMG_PREV_CE_1					794
#define IMG_PREV_CE_2					795
#define IMG_PREV_CE_3					796
#define IMG_PREV_CE_4					797
#define IMG_PREV_CE_5					798
#define IMG_PREV_CE_6					799
#define IMG_PREV_CE_7					800
#define IMG_PREV_CE_8					801
#define IMG_NEXT_CE_1					802
#define IMG_NEXT_CE_2					803
#define IMG_NEXT_CE_3					804
#define IMG_NEXT_CE_4					805
#define IMG_NEXT_CE_5					806
#define IMG_NEXT_CE_6					807
#define IMG_NEXT_CE_7					808
#define IMG_NEXT_CE_8					809
#define IMG_SELF					810
#define IMG_ANY_ELEMENT					811
#define IMG_EMC_KEY_5					812
#define IMG_EMC_KEY_6					813
#define IMG_EMC_KEY_7					814
#define IMG_EMC_KEY_8					815
#define IMG_EMC_GATE_5					816
#define IMG_EMC_GATE_6					817
#define IMG_EMC_GATE_7					818
#define IMG_EMC_GATE_8					819
#define IMG_EMC_GATE_5_GRAY				820
#define IMG_EMC_GATE_5_GRAY_EDITOR			821
#define IMG_EMC_GATE_5_GRAY_ACTIVE			822
#define IMG_EMC_GATE_6_GRAY				823
#define IMG_EMC_GATE_6_GRAY_EDITOR			824
#define IMG_EMC_GATE_6_GRAY_ACTIVE			825
#define IMG_EMC_GATE_7_GRAY				826
#define IMG_EMC_GATE_7_GRAY_EDITOR			827
#define IMG_EMC_GATE_7_GRAY_ACTIVE			828
#define IMG_EMC_GATE_8_GRAY				829
#define IMG_EMC_GATE_8_GRAY_EDITOR			830
#define IMG_EMC_GATE_8_GRAY_ACTIVE			831
#define IMG_EMC_ANDROID					832
#define IMG_EMC_ANDROID_SHRINKING_UPLEFT		833
#define IMG_EMC_ANDROID_GROWING_DOWNRIGHT		834
#define IMG_EMC_ANDROID_SHRINKING_DOWNLEFT		835
#define IMG_EMC_ANDROID_GROWING_UPRIGHT			836
#define IMG_EMC_ANDROID_SHRINKING_UPRIGHT		837
#define IMG_EMC_ANDROID_GROWING_DOWNLEFT		838
#define IMG_EMC_ANDROID_SHRINKING_DOWNRIGHT		839
#define IMG_EMC_ANDROID_GROWING_UPLEFT			840
#define IMG_EMC_GRASS					841
#define IMG_EMC_GRASS_CRUMBLED				842
#define IMG_EMC_GRASS_DIGGING_LEFT			843
#define IMG_EMC_GRASS_DIGGING_RIGHT			844
#define IMG_EMC_GRASS_DIGGING_UP			845
#define IMG_EMC_GRASS_DIGGING_DOWN			846
#define IMG_EMC_GRASS_DIGGING_LEFT_CRUMBLED		847
#define IMG_EMC_GRASS_DIGGING_RIGHT_CRUMBLED		848
#define IMG_EMC_GRASS_DIGGING_UP_CRUMBLED		849
#define IMG_EMC_GRASS_DIGGING_DOWN_CRUMBLED		850
#define IMG_EMC_MAGIC_BALL				851
#define IMG_EMC_MAGIC_BALL_ACTIVE			852
#define IMG_EMC_MAGIC_BALL_DROPPING			853
#define IMG_EMC_MAGIC_BALL_SWITCH			854
#define IMG_EMC_MAGIC_BALL_SWITCH_ACTIVE		855
#define IMG_EMC_SPRING_BUMPER				856
#define IMG_EMC_SPRING_BUMPER_ACTIVE			857
#define IMG_EMC_PLANT					858
#define IMG_EMC_PLANT_CRUMBLED				859
#define IMG_EMC_LENSES					860
#define IMG_EMC_MAGNIFIER				861
#define IMG_EMC_WALL_9					862
#define IMG_EMC_WALL_10					863
#define IMG_EMC_WALL_11					864
#define IMG_EMC_WALL_12					865
#define IMG_EMC_WALL_13					866
#define IMG_EMC_WALL_14					867
#define IMG_EMC_WALL_15					868
#define IMG_EMC_WALL_16					869
#define IMG_EMC_WALL_SLIPPERY_1				870
#define IMG_EMC_WALL_SLIPPERY_2				871
#define IMG_EMC_WALL_SLIPPERY_3				872
#define IMG_EMC_WALL_SLIPPERY_4				873
#define IMG_EMC_FAKE_GRASS				874
#define IMG_EMC_FAKE_GRASS_CRUMBLED			875
#define IMG_EMC_FAKE_GRASS_ACTIVE			876
#define IMG_EMC_FAKE_GRASS_ACTIVE_CRUMBLED		877
#define IMG_EMC_FAKE_GRASS_EDITOR			878
#define IMG_EMC_FAKE_ACID				879
#define IMG_EMC_DRIPPER					880
#define IMG_EMC_DRIPPER_EDITOR				881
#define IMG_EMC_DRIPPER_ACTIVE				882
#define IMG_GRAPHIC_1					883
#define IMG_GRAPHIC_2					884
#define IMG_GRAPHIC_3					885
#define IMG_GRAPHIC_4					886
#define IMG_GRAPHIC_5					887
#define IMG_GRAPHIC_6					888
#define IMG_GRAPHIC_7					889
#define IMG_GRAPHIC_8					890
#define IMG_CHAR_SPACE					891
#define IMG_CHAR_SPACE_EDITOR				892
#define IMG_CHAR_EXCLAM					893
#define IMG_CHAR_QUOTEDBL				894
#define IMG_CHAR_NUMBERSIGN				895
#define IMG_CHAR_DOLLAR					896
#define IMG_CHAR_PERCENT				897
#define IMG_CHAR_AMPERSAND				898
#define IMG_CHAR_APOSTROPHE				899
#define IMG_CHAR_PARENLEFT				900
#define IMG_CHAR_PARENRIGHT				901
#define IMG_CHAR_ASTERISK				902
#define IMG_CHAR_PLUS					903
#define IMG_CHAR_COMMA					904
#define IMG_CHAR_MINUS					905
#define IMG_CHAR_PERIOD					906
#define IMG_CHAR_SLASH					907
#define IMG_CHAR_0					908
#define IMG_CHAR_1					909
#define IMG_CHAR_2					910
#define IMG_CHAR_3					911
#define IMG_CHAR_4					912
#define IMG_CHAR_5					913
#define IMG_CHAR_6					914
#define IMG_CHAR_7					915
#define IMG_CHAR_8					916
#define IMG_CHAR_9					917
#define IMG_CHAR_COLON					918
#define IMG_CHAR_SEMICOLON				919
#define IMG_CHAR_LESS					920
#define IMG_CHAR_EQUAL					921
#define IMG_CHAR_GREATER				922
#define IMG_CHAR_QUESTION				923
#define IMG_CHAR_AT					924
#define IMG_CHAR_A					925
#define IMG_CHAR_B					926
#define IMG_CHAR_C					927
#define IMG_CHAR_D					928
#define IMG_CHAR_E					929
#define IMG_CHAR_F					930
#define IMG_CHAR_G					931
#define IMG_CHAR_H					932
#define IMG_CHAR_I					933
#define IMG_CHAR_J					934
#define IMG_CHAR_K					935
#define IMG_CHAR_L					936
#define IMG_CHAR_M					937
#define IMG_CHAR_N					938
#define IMG_CHAR_O					939
#define IMG_CHAR_P					940
#define IMG_CHAR_Q					941
#define IMG_CHAR_R					942
#define IMG_CHAR_S					943
#define IMG_CHAR_T					944
#define IMG_CHAR_U					945
#define IMG_CHAR_V					946
#define IMG_CHAR_W					947
#define IMG_CHAR_X					948
#define IMG_CHAR_Y					949
#define IMG_CHAR_Z					950
#define IMG_CHAR_BRACKETLEFT				951
#define IMG_CHAR_BACKSLASH				952
#define IMG_CHAR_BRACKETRIGHT				953
#define IMG_CHAR_ASCIICIRCUM				954
#define IMG_CHAR_UNDERSCORE				955
#define IMG_CHAR_COPYRIGHT				956
#define IMG_CHAR_AUMLAUT				957
#define IMG_CHAR_OUMLAUT				958
#define IMG_CHAR_UUMLAUT				959
#define IMG_CHAR_DEGREE					960
#define IMG_CHAR_TRADEMARK				961
#define IMG_CHAR_CURSOR					962
#define IMG_CHAR_BUTTON					963
#define IMG_CHAR_UP					964
#define IMG_CHAR_DOWN					965
#define IMG_STEEL_CHAR_SPACE				966
#define IMG_STEEL_CHAR_SPACE_EDITOR			967
#define IMG_STEEL_CHAR_EXCLAM				968
#define IMG_STEEL_CHAR_QUOTEDBL				969
#define IMG_STEEL_CHAR_NUMBERSIGN			970
#define IMG_STEEL_CHAR_DOLLAR				971
#define IMG_STEEL_CHAR_PERCENT				972
#define IMG_STEEL_CHAR_AMPERSAND			973
#define IMG_STEEL_CHAR_APOSTROPHE			974
#define IMG_STEEL_CHAR_PARENLEFT			975
#define IMG_STEEL_CHAR_PARENRIGHT			976
#define IMG_STEEL_CHAR_ASTERISK				977
#define IMG_STEEL_CHAR_PLUS				978
#define IMG_STEEL_CHAR_COMMA				979
#define IMG_STEEL_CHAR_MINUS				980
#define IMG_STEEL_CHAR_PERIOD				981
#define IMG_STEEL_CHAR_SLASH				982
#define IMG_STEEL_CHAR_0				983
#define IMG_STEEL_CHAR_1				984
#define IMG_STEEL_CHAR_2				985
#define IMG_STEEL_CHAR_3				986
#define IMG_STEEL_CHAR_4				987
#define IMG_STEEL_CHAR_5				988
#define IMG_STEEL_CHAR_6				989
#define IMG_STEEL_CHAR_7				990
#define IMG_STEEL_CHAR_8				991
#define IMG_STEEL_CHAR_9				992
#define IMG_STEEL_CHAR_COLON				993
#define IMG_STEEL_CHAR_SEMICOLON			994
#define IMG_STEEL_CHAR_LESS				995
#define IMG_STEEL_CHAR_EQUAL				996
#define IMG_STEEL_CHAR_GREATER				997
#define IMG_STEEL_CHAR_QUESTION				998
#define IMG_STEEL_CHAR_AT				999
#define IMG_STEEL_CHAR_A				1000
#define IMG_STEEL_CHAR_B				1001
#define IMG_STEEL_CHAR_C				1002
#define IMG_STEEL_CHAR_D				1003
#define IMG_STEEL_CHAR_E				1004
#define IMG_STEEL_CHAR_F				1005
#define IMG_STEEL_CHAR_G				1006
#define IMG_STEEL_CHAR_H				1007
#define IMG_STEEL_CHAR_I				1008
#define IMG_STEEL_CHAR_J				1009
#define IMG_STEEL_CHAR_K				1010
#define IMG_STEEL_CHAR_L				1011
#define IMG_STEEL_CHAR_M				1012
#define IMG_STEEL_CHAR_N				1013
#define IMG_STEEL_CHAR_O				1014
#define IMG_STEEL_CHAR_P				1015
#define IMG_STEEL_CHAR_Q				1016
#define IMG_STEEL_CHAR_R				1017
#define IMG_STEEL_CHAR_S				1018
#define IMG_STEEL_CHAR_T				1019
#define IMG_STEEL_CHAR_U				1020
#define IMG_STEEL_CHAR_V				1021
#define IMG_STEEL_CHAR_W				1022
#define IMG_STEEL_CHAR_X				1023
#define IMG_STEEL_CHAR_Y				1024
#define IMG_STEEL_CHAR_Z				1025
#define IMG_STEEL_CHAR_BRACKETLEFT			1026
#define IMG_STEEL_CHAR_BACKSLASH			1027
#define IMG_STEEL_CHAR_BRACKETRIGHT			1028
#define IMG_STEEL_CHAR_ASCIICIRCUM			1029
#define IMG_STEEL_CHAR_UNDERSCORE			1030
#define IMG_STEEL_CHAR_COPYRIGHT			1031
#define IMG_STEEL_CHAR_AUMLAUT				1032
#define IMG_STEEL_CHAR_OUMLAUT				1033
#define IMG_STEEL_CHAR_UUMLAUT				1034
#define IMG_STEEL_CHAR_DEGREE				1035
#define IMG_STEEL_CHAR_TRADEMARK			1036
#define IMG_STEEL_CHAR_CURSOR				1037
#define IMG_STEEL_CHAR_BUTTON				1038
#define IMG_STEEL_CHAR_UP				1039
#define IMG_STEEL_CHAR_DOWN				1040
#define IMG_CUSTOM_1					1041
#define IMG_CUSTOM_1_EDITOR				1042
#define IMG_CUSTOM_2					1043
#define IMG_CUSTOM_2_EDITOR				1044
#define IMG_CUSTOM_3					1045
#define IMG_CUSTOM_3_EDITOR				1046
#define IMG_CUSTOM_4					1047
#define IMG_CUSTOM_4_EDITOR				1048
#define IMG_CUSTOM_5					1049
#define IMG_CUSTOM_5_EDITOR				1050
#define IMG_CUSTOM_6					1051
#define IMG_CUSTOM_6_EDITOR				1052
#define IMG_CUSTOM_7					1053
#define IMG_CUSTOM_7_EDITOR				1054
#define IMG_CUSTOM_8					1055
#define IMG_CUSTOM_8_EDITOR				1056
#define IMG_CUSTOM_9					1057
#define IMG_CUSTOM_9_EDITOR				1058
#define IMG_CUSTOM_10					1059
#define IMG_CUSTOM_10_EDITOR				1060
#define IMG_CUSTOM_11					1061
#define IMG_CUSTOM_11_EDITOR				1062
#define IMG_CUSTOM_12					1063
#define IMG_CUSTOM_12_EDITOR				1064
#define IMG_CUSTOM_13					1065
#define IMG_CUSTOM_13_EDITOR				1066
#define IMG_CUSTOM_14					1067
#define IMG_CUSTOM_14_EDITOR				1068
#define IMG_CUSTOM_15					1069
#define IMG_CUSTOM_15_EDITOR				1070
#define IMG_CUSTOM_16					1071
#define IMG_CUSTOM_16_EDITOR				1072
#define IMG_CUSTOM_17					1073
#define IMG_CUSTOM_17_EDITOR				1074
#define IMG_CUSTOM_18					1075
#define IMG_CUSTOM_18_EDITOR				1076
#define IMG_CUSTOM_19					1077
#define IMG_CUSTOM_19_EDITOR				1078
#define IMG_CUSTOM_20					1079
#define IMG_CUSTOM_20_EDITOR				1080
#define IMG_CUSTOM_21					1081
#define IMG_CUSTOM_21_EDITOR				1082
#define IMG_CUSTOM_22					1083
#define IMG_CUSTOM_22_EDITOR				1084
#define IMG_CUSTOM_23					1085
#define IMG_CUSTOM_23_EDITOR				1086
#define IMG_CUSTOM_24					1087
#define IMG_CUSTOM_24_EDITOR				1088
#define IMG_CUSTOM_25					1089
#define IMG_CUSTOM_25_EDITOR				1090
#define IMG_CUSTOM_26					1091
#define IMG_CUSTOM_26_EDITOR				1092
#define IMG_CUSTOM_27					1093
#define IMG_CUSTOM_27_EDITOR				1094
#define IMG_CUSTOM_28					1095
#define IMG_CUSTOM_28_EDITOR				1096
#define IMG_CUSTOM_29					1097
#define IMG_CUSTOM_29_EDITOR				1098
#define IMG_CUSTOM_30					1099
#define IMG_CUSTOM_30_EDITOR				1100
#define IMG_CUSTOM_31					1101
#define IMG_CUSTOM_31_EDITOR				1102
#define IMG_CUSTOM_32					1103
#define IMG_CUSTOM_32_EDITOR				1104
#define IMG_CUSTOM_33					1105
#define IMG_CUSTOM_33_EDITOR				1106
#define IMG_CUSTOM_34					1107
#define IMG_CUSTOM_34_EDITOR				1108
#define IMG_CUSTOM_35					1109
#define IMG_CUSTOM_35_EDITOR				1110
#define IMG_CUSTOM_36					1111
#define IMG_CUSTOM_36_EDITOR				1112
#define IMG_CUSTOM_37					1113
#define IMG_CUSTOM_37_EDITOR				1114
#define IMG_CUSTOM_38					1115
#define IMG_CUSTOM_38_EDITOR				1116
#define IMG_CUSTOM_39					1117
#define IMG_CUSTOM_39_EDITOR				1118
#define IMG_CUSTOM_40					1119
#define IMG_CUSTOM_40_EDITOR				1120
#define IMG_CUSTOM_41					1121
#define IMG_CUSTOM_41_EDITOR				1122
#define IMG_CUSTOM_42					1123
#define IMG_CUSTOM_42_EDITOR				1124
#define IMG_CUSTOM_43					1125
#define IMG_CUSTOM_43_EDITOR				1126
#define IMG_CUSTOM_44					1127
#define IMG_CUSTOM_44_EDITOR				1128
#define IMG_CUSTOM_45					1129
#define IMG_CUSTOM_45_EDITOR				1130
#define IMG_CUSTOM_46					1131
#define IMG_CUSTOM_46_EDITOR				1132
#define IMG_CUSTOM_47					1133
#define IMG_CUSTOM_47_EDITOR				1134
#define IMG_CUSTOM_48					1135
#define IMG_CUSTOM_48_EDITOR				1136
#define IMG_CUSTOM_49					1137
#define IMG_CUSTOM_49_EDITOR				1138
#define IMG_CUSTOM_50					1139
#define IMG_CUSTOM_50_EDITOR				1140
#define IMG_CUSTOM_51					1141
#define IMG_CUSTOM_51_EDITOR				1142
#define IMG_CUSTOM_52					1143
#define IMG_CUSTOM_52_EDITOR				1144
#define IMG_CUSTOM_53					1145
#define IMG_CUSTOM_53_EDITOR				1146
#define IMG_CUSTOM_54					1147
#define IMG_CUSTOM_54_EDITOR				1148
#define IMG_CUSTOM_55					1149
#define IMG_CUSTOM_55_EDITOR				1150
#define IMG_CUSTOM_56					1151
#define IMG_CUSTOM_56_EDITOR				1152
#define IMG_CUSTOM_57					1153
#define IMG_CUSTOM_57_EDITOR				1154
#define IMG_CUSTOM_58					1155
#define IMG_CUSTOM_58_EDITOR				1156
#define IMG_CUSTOM_59					1157
#define IMG_CUSTOM_59_EDITOR				1158
#define IMG_CUSTOM_60					1159
#define IMG_CUSTOM_60_EDITOR				1160
#define IMG_CUSTOM_61					1161
#define IMG_CUSTOM_61_EDITOR				1162
#define IMG_CUSTOM_62					1163
#define IMG_CUSTOM_62_EDITOR				1164
#define IMG_CUSTOM_63					1165
#define IMG_CUSTOM_63_EDITOR				1166
#define IMG_CUSTOM_64					1167
#define IMG_CUSTOM_64_EDITOR				1168
#define IMG_CUSTOM_65					1169
#define IMG_CUSTOM_65_EDITOR				1170
#define IMG_CUSTOM_66					1171
#define IMG_CUSTOM_66_EDITOR				1172
#define IMG_CUSTOM_67					1173
#define IMG_CUSTOM_67_EDITOR				1174
#define IMG_CUSTOM_68					1175
#define IMG_CUSTOM_68_EDITOR				1176
#define IMG_CUSTOM_69					1177
#define IMG_CUSTOM_69_EDITOR				1178
#define IMG_CUSTOM_70					1179
#define IMG_CUSTOM_70_EDITOR				1180
#define IMG_CUSTOM_71					1181
#define IMG_CUSTOM_71_EDITOR				1182
#define IMG_CUSTOM_72					1183
#define IMG_CUSTOM_72_EDITOR				1184
#define IMG_CUSTOM_73					1185
#define IMG_CUSTOM_73_EDITOR				1186
#define IMG_CUSTOM_74					1187
#define IMG_CUSTOM_74_EDITOR				1188
#define IMG_CUSTOM_75					1189
#define IMG_CUSTOM_75_EDITOR				1190
#define IMG_CUSTOM_76					1191
#define IMG_CUSTOM_76_EDITOR				1192
#define IMG_CUSTOM_77					1193
#define IMG_CUSTOM_77_EDITOR				1194
#define IMG_CUSTOM_78					1195
#define IMG_CUSTOM_78_EDITOR				1196
#define IMG_CUSTOM_79					1197
#define IMG_CUSTOM_79_EDITOR				1198
#define IMG_CUSTOM_80					1199
#define IMG_CUSTOM_80_EDITOR				1200
#define IMG_CUSTOM_81					1201
#define IMG_CUSTOM_81_EDITOR				1202
#define IMG_CUSTOM_82					1203
#define IMG_CUSTOM_82_EDITOR				1204
#define IMG_CUSTOM_83					1205
#define IMG_CUSTOM_83_EDITOR				1206
#define IMG_CUSTOM_84					1207
#define IMG_CUSTOM_84_EDITOR				1208
#define IMG_CUSTOM_85					1209
#define IMG_CUSTOM_85_EDITOR				1210
#define IMG_CUSTOM_86					1211
#define IMG_CUSTOM_86_EDITOR				1212
#define IMG_CUSTOM_87					1213
#define IMG_CUSTOM_87_EDITOR				1214
#define IMG_CUSTOM_88					1215
#define IMG_CUSTOM_88_EDITOR				1216
#define IMG_CUSTOM_89					1217
#define IMG_CUSTOM_89_EDITOR				1218
#define IMG_CUSTOM_90					1219
#define IMG_CUSTOM_90_EDITOR				1220
#define IMG_CUSTOM_91					1221
#define IMG_CUSTOM_91_EDITOR				1222
#define IMG_CUSTOM_92					1223
#define IMG_CUSTOM_92_EDITOR				1224
#define IMG_CUSTOM_93					1225
#define IMG_CUSTOM_93_EDITOR				1226
#define IMG_CUSTOM_94					1227
#define IMG_CUSTOM_94_EDITOR				1228
#define IMG_CUSTOM_95					1229
#define IMG_CUSTOM_95_EDITOR				1230
#define IMG_CUSTOM_96					1231
#define IMG_CUSTOM_96_EDITOR				1232
#define IMG_CUSTOM_97					1233
#define IMG_CUSTOM_97_EDITOR				1234
#define IMG_CUSTOM_98					1235
#define IMG_CUSTOM_98_EDITOR				1236
#define IMG_CUSTOM_99					1237
#define IMG_CUSTOM_99_EDITOR				1238
#define IMG_CUSTOM_100					1239
#define IMG_CUSTOM_100_EDITOR				1240
#define IMG_CUSTOM_101					1241
#define IMG_CUSTOM_101_EDITOR				1242
#define IMG_CUSTOM_102					1243
#define IMG_CUSTOM_102_EDITOR				1244
#define IMG_CUSTOM_103					1245
#define IMG_CUSTOM_103_EDITOR				1246
#define IMG_CUSTOM_104					1247
#define IMG_CUSTOM_104_EDITOR				1248
#define IMG_CUSTOM_105					1249
#define IMG_CUSTOM_105_EDITOR				1250
#define IMG_CUSTOM_106					1251
#define IMG_CUSTOM_106_EDITOR				1252
#define IMG_CUSTOM_107					1253
#define IMG_CUSTOM_107_EDITOR				1254
#define IMG_CUSTOM_108					1255
#define IMG_CUSTOM_108_EDITOR				1256
#define IMG_CUSTOM_109					1257
#define IMG_CUSTOM_109_EDITOR				1258
#define IMG_CUSTOM_110					1259
#define IMG_CUSTOM_110_EDITOR				1260
#define IMG_CUSTOM_111					1261
#define IMG_CUSTOM_111_EDITOR				1262
#define IMG_CUSTOM_112					1263
#define IMG_CUSTOM_112_EDITOR				1264
#define IMG_CUSTOM_113					1265
#define IMG_CUSTOM_113_EDITOR				1266
#define IMG_CUSTOM_114					1267
#define IMG_CUSTOM_114_EDITOR				1268
#define IMG_CUSTOM_115					1269
#define IMG_CUSTOM_115_EDITOR				1270
#define IMG_CUSTOM_116					1271
#define IMG_CUSTOM_116_EDITOR				1272
#define IMG_CUSTOM_117					1273
#define IMG_CUSTOM_117_EDITOR				1274
#define IMG_CUSTOM_118					1275
#define IMG_CUSTOM_118_EDITOR				1276
#define IMG_CUSTOM_119					1277
#define IMG_CUSTOM_119_EDITOR				1278
#define IMG_CUSTOM_120					1279
#define IMG_CUSTOM_120_EDITOR				1280
#define IMG_CUSTOM_121					1281
#define IMG_CUSTOM_121_EDITOR				1282
#define IMG_CUSTOM_122					1283
#define IMG_CUSTOM_122_EDITOR				1284
#define IMG_CUSTOM_123					1285
#define IMG_CUSTOM_123_EDITOR				1286
#define IMG_CUSTOM_124					1287
#define IMG_CUSTOM_124_EDITOR				1288
#define IMG_CUSTOM_125					1289
#define IMG_CUSTOM_125_EDITOR				1290
#define IMG_CUSTOM_126					1291
#define IMG_CUSTOM_126_EDITOR				1292
#define IMG_CUSTOM_127					1293
#define IMG_CUSTOM_127_EDITOR				1294
#define IMG_CUSTOM_128					1295
#define IMG_CUSTOM_128_EDITOR				1296
#define IMG_CUSTOM_129					1297
#define IMG_CUSTOM_129_EDITOR				1298
#define IMG_CUSTOM_130					1299
#define IMG_CUSTOM_130_EDITOR				1300
#define IMG_CUSTOM_131					1301
#define IMG_CUSTOM_131_EDITOR				1302
#define IMG_CUSTOM_132					1303
#define IMG_CUSTOM_132_EDITOR				1304
#define IMG_CUSTOM_133					1305
#define IMG_CUSTOM_133_EDITOR				1306
#define IMG_CUSTOM_134					1307
#define IMG_CUSTOM_134_EDITOR				1308
#define IMG_CUSTOM_135					1309
#define IMG_CUSTOM_135_EDITOR				1310
#define IMG_CUSTOM_136					1311
#define IMG_CUSTOM_136_EDITOR				1312
#define IMG_CUSTOM_137					1313
#define IMG_CUSTOM_137_EDITOR				1314
#define IMG_CUSTOM_138					1315
#define IMG_CUSTOM_138_EDITOR				1316
#define IMG_CUSTOM_139					1317
#define IMG_CUSTOM_139_EDITOR				1318
#define IMG_CUSTOM_140					1319
#define IMG_CUSTOM_140_EDITOR				1320
#define IMG_CUSTOM_141					1321
#define IMG_CUSTOM_141_EDITOR				1322
#define IMG_CUSTOM_142					1323
#define IMG_CUSTOM_142_EDITOR				1324
#define IMG_CUSTOM_143					1325
#define IMG_CUSTOM_143_EDITOR				1326
#define IMG_CUSTOM_144					1327
#define IMG_CUSTOM_144_EDITOR				1328
#define IMG_CUSTOM_145					1329
#define IMG_CUSTOM_145_EDITOR				1330
#define IMG_CUSTOM_146					1331
#define IMG_CUSTOM_146_EDITOR				1332
#define IMG_CUSTOM_147					1333
#define IMG_CUSTOM_147_EDITOR				1334
#define IMG_CUSTOM_148					1335
#define IMG_CUSTOM_148_EDITOR				1336
#define IMG_CUSTOM_149					1337
#define IMG_CUSTOM_149_EDITOR				1338
#define IMG_CUSTOM_150					1339
#define IMG_CUSTOM_150_EDITOR				1340
#define IMG_CUSTOM_151					1341
#define IMG_CUSTOM_151_EDITOR				1342
#define IMG_CUSTOM_152					1343
#define IMG_CUSTOM_152_EDITOR				1344
#define IMG_CUSTOM_153					1345
#define IMG_CUSTOM_153_EDITOR				1346
#define IMG_CUSTOM_154					1347
#define IMG_CUSTOM_154_EDITOR				1348
#define IMG_CUSTOM_155					1349
#define IMG_CUSTOM_155_EDITOR				1350
#define IMG_CUSTOM_156					1351
#define IMG_CUSTOM_156_EDITOR				1352
#define IMG_CUSTOM_157					1353
#define IMG_CUSTOM_157_EDITOR				1354
#define IMG_CUSTOM_158					1355
#define IMG_CUSTOM_158_EDITOR				1356
#define IMG_CUSTOM_159					1357
#define IMG_CUSTOM_159_EDITOR				1358
#define IMG_CUSTOM_160					1359
#define IMG_CUSTOM_160_EDITOR				1360
#define IMG_CUSTOM_161					1361
#define IMG_CUSTOM_161_EDITOR				1362
#define IMG_CUSTOM_162					1363
#define IMG_CUSTOM_162_EDITOR				1364
#define IMG_CUSTOM_163					1365
#define IMG_CUSTOM_163_EDITOR				1366
#define IMG_CUSTOM_164					1367
#define IMG_CUSTOM_164_EDITOR				1368
#define IMG_CUSTOM_165					1369
#define IMG_CUSTOM_165_EDITOR				1370
#define IMG_CUSTOM_166					1371
#define IMG_CUSTOM_166_EDITOR				1372
#define IMG_CUSTOM_167					1373
#define IMG_CUSTOM_167_EDITOR				1374
#define IMG_CUSTOM_168					1375
#define IMG_CUSTOM_168_EDITOR				1376
#define IMG_CUSTOM_169					1377
#define IMG_CUSTOM_169_EDITOR				1378
#define IMG_CUSTOM_170					1379
#define IMG_CUSTOM_170_EDITOR				1380
#define IMG_CUSTOM_171					1381
#define IMG_CUSTOM_171_EDITOR				1382
#define IMG_CUSTOM_172					1383
#define IMG_CUSTOM_172_EDITOR				1384
#define IMG_CUSTOM_173					1385
#define IMG_CUSTOM_173_EDITOR				1386
#define IMG_CUSTOM_174					1387
#define IMG_CUSTOM_174_EDITOR				1388
#define IMG_CUSTOM_175					1389
#define IMG_CUSTOM_175_EDITOR				1390
#define IMG_CUSTOM_176					1391
#define IMG_CUSTOM_176_EDITOR				1392
#define IMG_CUSTOM_177					1393
#define IMG_CUSTOM_177_EDITOR				1394
#define IMG_CUSTOM_178					1395
#define IMG_CUSTOM_178_EDITOR				1396
#define IMG_CUSTOM_179					1397
#define IMG_CUSTOM_179_EDITOR				1398
#define IMG_CUSTOM_180					1399
#define IMG_CUSTOM_180_EDITOR				1400
#define IMG_CUSTOM_181					1401
#define IMG_CUSTOM_181_EDITOR				1402
#define IMG_CUSTOM_182					1403
#define IMG_CUSTOM_182_EDITOR				1404
#define IMG_CUSTOM_183					1405
#define IMG_CUSTOM_183_EDITOR				1406
#define IMG_CUSTOM_184					1407
#define IMG_CUSTOM_184_EDITOR				1408
#define IMG_CUSTOM_185					1409
#define IMG_CUSTOM_185_EDITOR				1410
#define IMG_CUSTOM_186					1411
#define IMG_CUSTOM_186_EDITOR				1412
#define IMG_CUSTOM_187					1413
#define IMG_CUSTOM_187_EDITOR				1414
#define IMG_CUSTOM_188					1415
#define IMG_CUSTOM_188_EDITOR				1416
#define IMG_CUSTOM_189					1417
#define IMG_CUSTOM_189_EDITOR				1418
#define IMG_CUSTOM_190					1419
#define IMG_CUSTOM_190_EDITOR				1420
#define IMG_CUSTOM_191					1421
#define IMG_CUSTOM_191_EDITOR				1422
#define IMG_CUSTOM_192					1423
#define IMG_CUSTOM_192_EDITOR				1424
#define IMG_CUSTOM_193					1425
#define IMG_CUSTOM_193_EDITOR				1426
#define IMG_CUSTOM_194					1427
#define IMG_CUSTOM_194_EDITOR				1428
#define IMG_CUSTOM_195					1429
#define IMG_CUSTOM_195_EDITOR				1430
#define IMG_CUSTOM_196					1431
#define IMG_CUSTOM_196_EDITOR				1432
#define IMG_CUSTOM_197					1433
#define IMG_CUSTOM_197_EDITOR				1434
#define IMG_CUSTOM_198					1435
#define IMG_CUSTOM_198_EDITOR				1436
#define IMG_CUSTOM_199					1437
#define IMG_CUSTOM_199_EDITOR				1438
#define IMG_CUSTOM_200					1439
#define IMG_CUSTOM_200_EDITOR				1440
#define IMG_CUSTOM_201					1441
#define IMG_CUSTOM_201_EDITOR				1442
#define IMG_CUSTOM_202					1443
#define IMG_CUSTOM_202_EDITOR				1444
#define IMG_CUSTOM_203					1445
#define IMG_CUSTOM_203_EDITOR				1446
#define IMG_CUSTOM_204					1447
#define IMG_CUSTOM_204_EDITOR				1448
#define IMG_CUSTOM_205					1449
#define IMG_CUSTOM_205_EDITOR				1450
#define IMG_CUSTOM_206					1451
#define IMG_CUSTOM_206_EDITOR				1452
#define IMG_CUSTOM_207					1453
#define IMG_CUSTOM_207_EDITOR				1454
#define IMG_CUSTOM_208					1455
#define IMG_CUSTOM_208_EDITOR				1456
#define IMG_CUSTOM_209					1457
#define IMG_CUSTOM_209_EDITOR				1458
#define IMG_CUSTOM_210					1459
#define IMG_CUSTOM_210_EDITOR				1460
#define IMG_CUSTOM_211					1461
#define IMG_CUSTOM_211_EDITOR				1462
#define IMG_CUSTOM_212					1463
#define IMG_CUSTOM_212_EDITOR				1464
#define IMG_CUSTOM_213					1465
#define IMG_CUSTOM_213_EDITOR				1466
#define IMG_CUSTOM_214					1467
#define IMG_CUSTOM_214_EDITOR				1468
#define IMG_CUSTOM_215					1469
#define IMG_CUSTOM_215_EDITOR				1470
#define IMG_CUSTOM_216					1471
#define IMG_CUSTOM_216_EDITOR				1472
#define IMG_CUSTOM_217					1473
#define IMG_CUSTOM_217_EDITOR				1474
#define IMG_CUSTOM_218					1475
#define IMG_CUSTOM_218_EDITOR				1476
#define IMG_CUSTOM_219					1477
#define IMG_CUSTOM_219_EDITOR				1478
#define IMG_CUSTOM_220					1479
#define IMG_CUSTOM_220_EDITOR				1480
#define IMG_CUSTOM_221					1481
#define IMG_CUSTOM_221_EDITOR				1482
#define IMG_CUSTOM_222					1483
#define IMG_CUSTOM_222_EDITOR				1484
#define IMG_CUSTOM_223					1485
#define IMG_CUSTOM_223_EDITOR				1486
#define IMG_CUSTOM_224					1487
#define IMG_CUSTOM_224_EDITOR				1488
#define IMG_CUSTOM_225					1489
#define IMG_CUSTOM_225_EDITOR				1490
#define IMG_CUSTOM_226					1491
#define IMG_CUSTOM_226_EDITOR				1492
#define IMG_CUSTOM_227					1493
#define IMG_CUSTOM_227_EDITOR				1494
#define IMG_CUSTOM_228					1495
#define IMG_CUSTOM_228_EDITOR				1496
#define IMG_CUSTOM_229					1497
#define IMG_CUSTOM_229_EDITOR				1498
#define IMG_CUSTOM_230					1499
#define IMG_CUSTOM_230_EDITOR				1500
#define IMG_CUSTOM_231					1501
#define IMG_CUSTOM_231_EDITOR				1502
#define IMG_CUSTOM_232					1503
#define IMG_CUSTOM_232_EDITOR				1504
#define IMG_CUSTOM_233					1505
#define IMG_CUSTOM_233_EDITOR				1506
#define IMG_CUSTOM_234					1507
#define IMG_CUSTOM_234_EDITOR				1508
#define IMG_CUSTOM_235					1509
#define IMG_CUSTOM_235_EDITOR				1510
#define IMG_CUSTOM_236					1511
#define IMG_CUSTOM_236_EDITOR				1512
#define IMG_CUSTOM_237					1513
#define IMG_CUSTOM_237_EDITOR				1514
#define IMG_CUSTOM_238					1515
#define IMG_CUSTOM_238_EDITOR				1516
#define IMG_CUSTOM_239					1517
#define IMG_CUSTOM_239_EDITOR				1518
#define IMG_CUSTOM_240					1519
#define IMG_CUSTOM_240_EDITOR				1520
#define IMG_CUSTOM_241					1521
#define IMG_CUSTOM_241_EDITOR				1522
#define IMG_CUSTOM_242					1523
#define IMG_CUSTOM_242_EDITOR				1524
#define IMG_CUSTOM_243					1525
#define IMG_CUSTOM_243_EDITOR				1526
#define IMG_CUSTOM_244					1527
#define IMG_CUSTOM_244_EDITOR				1528
#define IMG_CUSTOM_245					1529
#define IMG_CUSTOM_245_EDITOR				1530
#define IMG_CUSTOM_246					1531
#define IMG_CUSTOM_246_EDITOR				1532
#define IMG_CUSTOM_247					1533
#define IMG_CUSTOM_247_EDITOR				1534
#define IMG_CUSTOM_248					1535
#define IMG_CUSTOM_248_EDITOR				1536
#define IMG_CUSTOM_249					1537
#define IMG_CUSTOM_249_EDITOR				1538
#define IMG_CUSTOM_250					1539
#define IMG_CUSTOM_250_EDITOR				1540
#define IMG_CUSTOM_251					1541
#define IMG_CUSTOM_251_EDITOR				1542
#define IMG_CUSTOM_252					1543
#define IMG_CUSTOM_252_EDITOR				1544
#define IMG_CUSTOM_253					1545
#define IMG_CUSTOM_253_EDITOR				1546
#define IMG_CUSTOM_254					1547
#define IMG_CUSTOM_254_EDITOR				1548
#define IMG_CUSTOM_255					1549
#define IMG_CUSTOM_255_EDITOR				1550
#define IMG_CUSTOM_256					1551
#define IMG_CUSTOM_256_EDITOR				1552
#define IMG_GROUP_1					1553
#define IMG_GROUP_1_EDITOR				1554
#define IMG_GROUP_2					1555
#define IMG_GROUP_2_EDITOR				1556
#define IMG_GROUP_3					1557
#define IMG_GROUP_3_EDITOR				1558
#define IMG_GROUP_4					1559
#define IMG_GROUP_4_EDITOR				1560
#define IMG_GROUP_5					1561
#define IMG_GROUP_5_EDITOR				1562
#define IMG_GROUP_6					1563
#define IMG_GROUP_6_EDITOR				1564
#define IMG_GROUP_7					1565
#define IMG_GROUP_7_EDITOR				1566
#define IMG_GROUP_8					1567
#define IMG_GROUP_8_EDITOR				1568
#define IMG_GROUP_9					1569
#define IMG_GROUP_9_EDITOR				1570
#define IMG_GROUP_10					1571
#define IMG_GROUP_10_EDITOR				1572
#define IMG_GROUP_11					1573
#define IMG_GROUP_11_EDITOR				1574
#define IMG_GROUP_12					1575
#define IMG_GROUP_12_EDITOR				1576
#define IMG_GROUP_13					1577
#define IMG_GROUP_13_EDITOR				1578
#define IMG_GROUP_14					1579
#define IMG_GROUP_14_EDITOR				1580
#define IMG_GROUP_15					1581
#define IMG_GROUP_15_EDITOR				1582
#define IMG_GROUP_16					1583
#define IMG_GROUP_16_EDITOR				1584
#define IMG_GROUP_17					1585
#define IMG_GROUP_17_EDITOR				1586
#define IMG_GROUP_18					1587
#define IMG_GROUP_18_EDITOR				1588
#define IMG_GROUP_19					1589
#define IMG_GROUP_19_EDITOR				1590
#define IMG_GROUP_20					1591
#define IMG_GROUP_20_EDITOR				1592
#define IMG_GROUP_21					1593
#define IMG_GROUP_21_EDITOR				1594
#define IMG_GROUP_22					1595
#define IMG_GROUP_22_EDITOR				1596
#define IMG_GROUP_23					1597
#define IMG_GROUP_23_EDITOR				1598
#define IMG_GROUP_24					1599
#define IMG_GROUP_24_EDITOR				1600
#define IMG_GROUP_25					1601
#define IMG_GROUP_25_EDITOR				1602
#define IMG_GROUP_26					1603
#define IMG_GROUP_26_EDITOR				1604
#define IMG_GROUP_27					1605
#define IMG_GROUP_27_EDITOR				1606
#define IMG_GROUP_28					1607
#define IMG_GROUP_28_EDITOR				1608
#define IMG_GROUP_29					1609
#define IMG_GROUP_29_EDITOR				1610
#define IMG_GROUP_30					1611
#define IMG_GROUP_30_EDITOR				1612
#define IMG_GROUP_31					1613
#define IMG_GROUP_31_EDITOR				1614
#define IMG_GROUP_32					1615
#define IMG_GROUP_32_EDITOR				1616
#define IMG_EMC_OBJECT					1617
#define IMG_EMC_SPRITE					1618
#define IMG_SP_FRAME_HORIZONTAL				1619
#define IMG_SP_FRAME_VERTICAL				1620
#define IMG_SP_FRAME_CORNER				1621
#define IMG_TOON_1					1622
#define IMG_TOON_2					1623
#define IMG_TOON_3					1624
#define IMG_TOON_4					1625
#define IMG_TOON_5					1626
#define IMG_TOON_6					1627
#define IMG_TOON_7					1628
#define IMG_TOON_8					1629
#define IMG_TOON_9					1630
#define IMG_TOON_10					1631
#define IMG_TOON_11					1632
#define IMG_TOON_12					1633
#define IMG_TOON_13					1634
#define IMG_TOON_14					1635
#define IMG_TOON_15					1636
#define IMG_TOON_16					1637
#define IMG_TOON_17					1638
#define IMG_TOON_18					1639
#define IMG_TOON_19					1640
#define IMG_TOON_20					1641
#define IMG_MENU_CALIBRATE_RED				1642
#define IMG_MENU_CALIBRATE_BLUE				1643
#define IMG_MENU_CALIBRATE_YELLOW			1644
#define IMG_MENU_BUTTON					1645
#define IMG_MENU_BUTTON_ACTIVE				1646
#define IMG_MENU_BUTTON_LEFT				1647
#define IMG_MENU_BUTTON_LEFT_ACTIVE			1648
#define IMG_MENU_BUTTON_RIGHT				1649
#define IMG_MENU_BUTTON_RIGHT_ACTIVE			1650
#define IMG_MENU_BUTTON_UP				1651
#define IMG_MENU_BUTTON_UP_ACTIVE			1652
#define IMG_MENU_BUTTON_DOWN				1653
#define IMG_MENU_BUTTON_DOWN_ACTIVE			1654
#define IMG_MENU_BUTTON_ENTER_MENU			1655
#define IMG_MENU_BUTTON_ENTER_MENU_ACTIVE		1656
#define IMG_MENU_BUTTON_LEAVE_MENU			1657
#define IMG_MENU_BUTTON_LEAVE_MENU_ACTIVE		1658
#define IMG_MENU_BUTTON_NEXT_LEVEL			1659
#define IMG_MENU_BUTTON_NEXT_LEVEL_ACTIVE		1660
#define IMG_MENU_BUTTON_PREV_LEVEL			1661
#define IMG_MENU_BUTTON_PREV_LEVEL_ACTIVE		1662
#define IMG_MENU_BUTTON_NAME				1663
#define IMG_MENU_BUTTON_NAME_ACTIVE			1664
#define IMG_MENU_BUTTON_LEVELS				1665
#define IMG_MENU_BUTTON_LEVELS_ACTIVE			1666
#define IMG_MENU_BUTTON_SCORES				1667
#define IMG_MENU_BUTTON_SCORES_ACTIVE			1668
#define IMG_MENU_BUTTON_EDITOR				1669
#define IMG_MENU_BUTTON_EDITOR_ACTIVE			1670
#define IMG_MENU_BUTTON_INFO				1671
#define IMG_MENU_BUTTON_INFO_ACTIVE			1672
#define IMG_MENU_BUTTON_GAME				1673
#define IMG_MENU_BUTTON_GAME_ACTIVE			1674
#define IMG_MENU_BUTTON_SETUP				1675
#define IMG_MENU_BUTTON_SETUP_ACTIVE			1676
#define IMG_MENU_BUTTON_QUIT				1677
#define IMG_MENU_BUTTON_QUIT_ACTIVE			1678
#define IMG_MENU_SCROLLBAR				1679
#define IMG_MENU_SCROLLBAR_ACTIVE			1680
#define IMG_GAME_BUTTON_GFX_STOP			1681
#define IMG_GAME_BUTTON_GFX_PAUSE			1682
#define IMG_GAME_BUTTON_GFX_PLAY			1683
#define IMG_GAME_BUTTON_GFX_SOUND_MUSIC			1684
#define IMG_GAME_BUTTON_GFX_SOUND_LOOPS			1685
#define IMG_GAME_BUTTON_GFX_SOUND_SIMPLE		1686
#define IMG_TAPE_BUTTON_GFX_EJECT			1687
#define IMG_TAPE_BUTTON_GFX_EXTRA			1688
#define IMG_TAPE_BUTTON_GFX_STOP			1689
#define IMG_TAPE_BUTTON_GFX_PAUSE			1690
#define IMG_TAPE_BUTTON_GFX_RECORD			1691
#define IMG_TAPE_BUTTON_GFX_PLAY			1692
#define IMG_TAPE_SYMBOL_GFX_EJECT			1693
#define IMG_TAPE_SYMBOL_GFX_STOP			1694
#define IMG_TAPE_SYMBOL_GFX_PAUSE			1695
#define IMG_TAPE_SYMBOL_GFX_RECORD			1696
#define IMG_TAPE_SYMBOL_GFX_PLAY			1697
#define IMG_TAPE_SYMBOL_GFX_FAST_FORWARD		1698
#define IMG_TAPE_SYMBOL_GFX_WARP_FORWARD		1699
#define IMG_TAPE_SYMBOL_GFX_WARP_FORWARD_BLIND		1700
#define IMG_TAPE_SYMBOL_GFX_PAUSE_BEFORE_END		1701
#define IMG_TAPE_SYMBOL_GFX_SINGLE_STEP			1702
#define IMG_TAPE_LABEL_GFX_EJECT			1703
#define IMG_TAPE_LABEL_GFX_STOP				1704
#define IMG_TAPE_LABEL_GFX_PAUSE			1705
#define IMG_TAPE_LABEL_GFX_RECORD			1706
#define IMG_TAPE_LABEL_GFX_PLAY				1707
#define IMG_TAPE_LABEL_GFX_FAST_FORWARD			1708
#define IMG_TAPE_LABEL_GFX_WARP_FORWARD			1709
#define IMG_TAPE_LABEL_GFX_WARP_FORWARD_BLIND		1710
#define IMG_TAPE_LABEL_GFX_PAUSE_BEFORE_END		1711
#define IMG_TAPE_LABEL_GFX_SINGLE_STEP			1712
#define IMG_TAPE_LABEL_GFX_DATE				1713
#define IMG_TAPE_LABEL_GFX_TIME				1714
#define IMG_FONT_INITIAL_1				1715
#define IMG_FONT_INITIAL_2				1716
#define IMG_FONT_INITIAL_3				1717
#define IMG_FONT_INITIAL_4				1718
#define IMG_FONT_TITLE_1				1719
#define IMG_FONT_TITLE_2				1720
#define IMG_FONT_TITLE_2_SETUP				1721
#define IMG_FONT_MENU_1					1722
#define IMG_FONT_MENU_1_ACTIVE				1723
#define IMG_FONT_MENU_2					1724
#define IMG_FONT_MENU_2_ACTIVE				1725
#define IMG_FONT_TEXT_1					1726
#define IMG_FONT_TEXT_1_MAIN				1727
#define IMG_FONT_TEXT_1_LEVELS				1728
#define IMG_FONT_TEXT_1_LEVELNR				1729
#define IMG_FONT_TEXT_1_SETUP				1730
#define IMG_FONT_TEXT_1_PREVIEW				1731
#define IMG_FONT_TEXT_1_SCORES				1732
#define IMG_FONT_TEXT_1_ACTIVE_SCORES			1733
#define IMG_FONT_TEXT_1_PANEL				1734
#define IMG_FONT_TEXT_1_DOOR				1735
#define IMG_FONT_TEXT_2					1736
#define IMG_FONT_TEXT_2_MAIN				1737
#define IMG_FONT_TEXT_2_LEVELS				1738
#define IMG_FONT_TEXT_2_LEVELNR				1739
#define IMG_FONT_TEXT_2_SETUP				1740
#define IMG_FONT_TEXT_2_PREVIEW				1741
#define IMG_FONT_TEXT_2_SCORES				1742
#define IMG_FONT_TEXT_2_ACTIVE_SCORES			1743
#define IMG_FONT_TEXT_3					1744
#define IMG_FONT_TEXT_3_LEVELS				1745
#define IMG_FONT_TEXT_3_LEVELNR				1746
#define IMG_FONT_TEXT_3_SETUP				1747
#define IMG_FONT_TEXT_3_PREVIEW				1748
#define IMG_FONT_TEXT_3_SCORES				1749
#define IMG_FONT_TEXT_3_ACTIVE_SCORES			1750
#define IMG_FONT_TEXT_4					1751
#define IMG_FONT_TEXT_4_MAIN				1752
#define IMG_FONT_TEXT_4_LEVELS				1753
#define IMG_FONT_TEXT_4_LEVELNR				1754
#define IMG_FONT_TEXT_4_SETUP				1755
#define IMG_FONT_TEXT_4_SCORES				1756
#define IMG_FONT_TEXT_4_ACTIVE_SCORES			1757
#define IMG_FONT_ENVELOPE_1				1758
#define IMG_FONT_ENVELOPE_2				1759
#define IMG_FONT_ENVELOPE_3				1760
#define IMG_FONT_ENVELOPE_4				1761
#define IMG_FONT_INPUT_1				1762
#define IMG_FONT_INPUT_1_MAIN				1763
#define IMG_FONT_INPUT_1_ACTIVE				1764
#define IMG_FONT_INPUT_1_ACTIVE_MAIN			1765
#define IMG_FONT_INPUT_1_ACTIVE_SETUP			1766
#define IMG_FONT_INPUT_2				1767
#define IMG_FONT_INPUT_2_ACTIVE				1768
#define IMG_FONT_OPTION_OFF				1769
#define IMG_FONT_OPTION_ON				1770
#define IMG_FONT_VALUE_1				1771
#define IMG_FONT_VALUE_2				1772
#define IMG_FONT_VALUE_OLD				1773
#define IMG_FONT_LEVEL_NUMBER				1774
#define IMG_FONT_LEVEL_NUMBER_ACTIVE			1775
#define IMG_FONT_TAPE_RECORDER				1776
#define IMG_FONT_GAME_INFO				1777
#define IMG_FONT_INFO_ELEMENTS				1778
#define IMG_FONT_INFO_LEVELSET				1779
#define IMG_GLOBAL_BORDER				1780
#define IMG_GLOBAL_DOOR					1781
#define IMG_GLOBAL_BUSY					1782
#define IMG_EDITOR_ELEMENT_BORDER			1783
#define IMG_EDITOR_ELEMENT_BORDER_INPUT			1784
#define IMG_EDITOR_CASCADE_LIST				1785
#define IMG_EDITOR_CASCADE_LIST_ACTIVE			1786
#define IMG_BACKGROUND					1787
#define IMG_BACKGROUND_TITLE_INITIAL			1788
#define IMG_BACKGROUND_TITLE				1789
#define IMG_BACKGROUND_MAIN				1790
#define IMG_BACKGROUND_LEVELS				1791
#define IMG_BACKGROUND_LEVELNR				1792
#define IMG_BACKGROUND_SCORES				1793
#define IMG_BACKGROUND_EDITOR				1794
#define IMG_BACKGROUND_INFO				1795
#define IMG_BACKGROUND_INFO_ELEMENTS			1796
#define IMG_BACKGROUND_INFO_MUSIC			1797
#define IMG_BACKGROUND_INFO_CREDITS			1798
#define IMG_BACKGROUND_INFO_PROGRAM			1799
#define IMG_BACKGROUND_INFO_VERSION			1800
#define IMG_BACKGROUND_INFO_LEVELSET			1801
#define IMG_BACKGROUND_SETUP				1802
#define IMG_BACKGROUND_PLAYING				1803
#define IMG_BACKGROUND_DOOR				1804
#define IMG_BACKGROUND_TAPE				1805
#define IMG_BACKGROUND_PANEL				1806
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_1		1807
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_2		1808
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_3		1809
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_4		1810
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_5		1811
#define IMG_BACKGROUND_TITLESCREEN_1			1812
#define IMG_BACKGROUND_TITLESCREEN_2			1813
#define IMG_BACKGROUND_TITLESCREEN_3			1814
#define IMG_BACKGROUND_TITLESCREEN_4			1815
#define IMG_BACKGROUND_TITLESCREEN_5			1816
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_1		1817
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_2		1818
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_3		1819
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_4		1820
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_5		1821
#define IMG_BACKGROUND_TITLEMESSAGE_1			1822
#define IMG_BACKGROUND_TITLEMESSAGE_2			1823
#define IMG_BACKGROUND_TITLEMESSAGE_3			1824
#define IMG_BACKGROUND_TITLEMESSAGE_4			1825
#define IMG_BACKGROUND_TITLEMESSAGE_5			1826
#define IMG_BACKGROUND_ENVELOPE_1			1827
#define IMG_BACKGROUND_ENVELOPE_2			1828
#define IMG_BACKGROUND_ENVELOPE_3			1829
#define IMG_BACKGROUND_ENVELOPE_4			1830
#define IMG_TITLESCREEN_INITIAL_1			1831
#define IMG_TITLESCREEN_INITIAL_2			1832
#define IMG_TITLESCREEN_INITIAL_3			1833
#define IMG_TITLESCREEN_INITIAL_4			1834
#define IMG_TITLESCREEN_INITIAL_5			1835
#define IMG_TITLESCREEN_1				1836
#define IMG_TITLESCREEN_2				1837
#define IMG_TITLESCREEN_3				1838
#define IMG_TITLESCREEN_4				1839
#define IMG_TITLESCREEN_5				1840

#define NUM_IMAGE_FILES					1841

#endif	/* CONF_GFX_H */
