/***********************************************************
* Rocks'n'Diamonds -- McDuffin Strikes Back!               *
*----------------------------------------------------------*
* (c) 1995-2006 Artsoft Entertainment                      *
*               Holger Schemel                             *
*               Detmolder Strasse 189                      *
*               33604 Bielefeld                            *
*               Germany                                    *
*               e-mail: info@artsoft.org                   *
*----------------------------------------------------------*
* conf_mus.h                                               *
***********************************************************/

/* ----- this file was automatically generated -- do not edit by hand ----- */

#ifndef CONF_MUS_H
#define CONF_MUS_H

/* values for music configuration */

#define MUS_BACKGROUND					0
#define MUS_BACKGROUND_TITLE_INITIAL			1
#define MUS_BACKGROUND_TITLE				2
#define MUS_BACKGROUND_MAIN				3
#define MUS_BACKGROUND_LEVELS				4
#define MUS_BACKGROUND_SCORES				5
#define MUS_BACKGROUND_EDITOR				6
#define MUS_BACKGROUND_INFO				7
#define MUS_BACKGROUND_SETUP				8
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_1		9
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_2		10
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_3		11
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_4		12
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_5		13
#define MUS_BACKGROUND_TITLESCREEN_1			14
#define MUS_BACKGROUND_TITLESCREEN_2			15
#define MUS_BACKGROUND_TITLESCREEN_3			16
#define MUS_BACKGROUND_TITLESCREEN_4			17
#define MUS_BACKGROUND_TITLESCREEN_5			18
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_1		19
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_2		20
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_3		21
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_4		22
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_5		23
#define MUS_BACKGROUND_TITLEMESSAGE_1			24
#define MUS_BACKGROUND_TITLEMESSAGE_2			25
#define MUS_BACKGROUND_TITLEMESSAGE_3			26
#define MUS_BACKGROUND_TITLEMESSAGE_4			27
#define MUS_BACKGROUND_TITLEMESSAGE_5			28

#define NUM_MUSIC_FILES					29

#endif	/* CONF_MUS_H */
