// ----------------------------------------------------------------------------
// Electrons.h
// ----------------------------------------------------------------------------

#ifndef ELECTRONS_H
#define ELECTRONS_H

#include "global.h"


extern void subAnimateElectrons(int);
extern void subDrawAnimatedElectrons(int);
extern void subDrawElectronFromAbove(int, int);
extern void subDrawElectronFromBelow(int, int);
extern void subDrawElectronFromLeft(int, int);
extern void subDrawElectronFromRight(int, int);
extern void subDrawElectronTurnLeft(int, int);
extern void subDrawElectronTurnRight(int, int);
extern void subElectronFromAbove(int, int);
extern void subElectronFromBelow(int, int);
extern void subElectronFromLeft(int, int);
extern void subElectronFromRight(int, int);
extern void subElectronTurnLeft(int, int);
extern void subElectronTurnRight(int, int);

#endif /* ELECTRONS_H */
