/***********************************************************
* Rocks'n'Diamonds -- McDuffin Strikes Back!               *
*----------------------------------------------------------*
* (c) 1995-2006 Artsoft Entertainment                      *
*               Holger Schemel                             *
*               Detmolder Strasse 189                      *
*               33604 Bielefeld                            *
*               Germany                                    *
*               e-mail: info@artsoft.org                   *
*----------------------------------------------------------*
* config.h                                                 *
***********************************************************/

#ifndef CONFIG_H
#define CONFIG_H

#include "main.h"

char *getCompileDateString(void);
char *getProgramReleaseVersionString(void);
char *getProgramFullVersionString(void);
char *getProgramVersionString(void);
char *getProgramInitString(void);
char *getWindowTitleString(void);

#endif	/* CONFIG_H */
